"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .dto_addonresponse import DtoAddonResponse, DtoAddonResponseTypedDict
from .dto_entitlementresponse import (
    DtoEntitlementResponse,
    DtoEntitlementResponseTypedDict,
)
from .dto_invoiceresponse import DtoInvoiceResponse, DtoInvoiceResponseTypedDict
from .dto_planresponse import DtoPlanResponse, DtoPlanResponseTypedDict
from .dto_priceresponse import DtoPriceResponse, DtoPriceResponseTypedDict
from .dto_subscriptionresponse import (
    DtoSubscriptionResponse,
    DtoSubscriptionResponseTypedDict,
)
from typing import Any, TYPE_CHECKING

from flexprice_py.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .addonassociationentitytype import AddonAssociationEntityType
    from .addonfilter import AddonFilter, AddonFilterOrder, AddonFilterTypedDict
    from .addonstatus import AddonStatus
    from .addontype import AddonType
    from .aggregationtype import AggregationType
    from .alertcondition import AlertCondition
    from .alertentitytype import AlertEntityType
    from .alertinfo import AlertInfo, AlertInfoTypedDict
    from .alertlogfilter import (
        AlertLogFilter,
        AlertLogFilterOrder,
        AlertLogFilterTypedDict,
    )
    from .alertsettings import AlertSettings, AlertSettingsTypedDict
    from .alertstate import AlertState
    from .alertthreshold import AlertThreshold, AlertThresholdTypedDict
    from .alerttype import AlertType
    from .applicationstatus import ApplicationStatus
    from .autotopup import AutoTopup, AutoTopupTypedDict
    from .billingcadence import BillingCadence
    from .billingcycle import BillingCycle
    from .billingmodel import BillingModel
    from .billingperiod import BillingPeriod
    from .billingtier import BillingTier
    from .cancelimmediatelyinvoicepolicy import CancelImmediatelyInvoicePolicy
    from .cancellationtype import CancellationType
    from .collectionmethod import CollectionMethod
    from .commitmentinfo import CommitmentInfo, CommitmentInfoTypedDict
    from .commitmenttype import CommitmentType
    from .costsheet_filter import CostsheetFilter, CostsheetFilterTypedDict
    from .couponcadence import CouponCadence
    from .couponfilter import CouponFilter, CouponFilterOrder, CouponFilterTypedDict
    from .coupontype import CouponType
    from .creditbreakdown import CreditBreakdown, CreditBreakdownTypedDict
    from .creditgrantapplicationreason import CreditGrantApplicationReason
    from .creditgrantcadence import CreditGrantCadence
    from .creditgrantexpirydurationunit import CreditGrantExpiryDurationUnit
    from .creditgrantexpirytype import CreditGrantExpiryType
    from .creditgrantperiod import CreditGrantPeriod
    from .creditgrantscope import CreditGrantScope
    from .creditnote_creditnotelineitem import (
        CreditnoteCreditNoteLineItem,
        CreditnoteCreditNoteLineItemTypedDict,
    )
    from .creditnotereason import CreditNoteReason
    from .creditnotestatus import CreditNoteStatus
    from .creditnotetype import CreditNoteType
    from .customerfilter import (
        CustomerFilter,
        CustomerFilterOrder,
        CustomerFilterTypedDict,
    )
    from .datatype import DataType
    from .debugtrackerstatus import DebugTrackerStatus
    from .dto_activatedraftsubscriptionrequest import (
        DtoActivateDraftSubscriptionRequest,
        DtoActivateDraftSubscriptionRequestTypedDict,
    )
    from .dto_addaddonrequest import DtoAddAddonRequest, DtoAddAddonRequestTypedDict
    from .dto_addaddontosubscriptionrequest import (
        DtoAddAddonToSubscriptionRequest,
        DtoAddAddonToSubscriptionRequestTypedDict,
    )
    from .dto_addonassociationresponse import (
        DtoAddonAssociationResponse,
        DtoAddonAssociationResponseTypedDict,
    )
    from .dto_address import DtoAddress, DtoAddressTypedDict
    from .dto_aggregatedentitlement import (
        DtoAggregatedEntitlement,
        DtoAggregatedEntitlementTypedDict,
    )
    from .dto_aggregatedfeature import (
        DtoAggregatedFeature,
        DtoAggregatedFeatureTypedDict,
    )
    from .dto_alertlogresponse import DtoAlertLogResponse, DtoAlertLogResponseTypedDict
    from .dto_billingcycleinfo import DtoBillingCycleInfo, DtoBillingCycleInfoTypedDict
    from .dto_billingperiodinfo import (
        DtoBillingPeriodInfo,
        DtoBillingPeriodInfoTypedDict,
    )
    from .dto_bulkingesteventrequest import (
        DtoBulkIngestEventRequest,
        DtoBulkIngestEventRequestTypedDict,
    )
    from .dto_cancelschedulerequest import (
        DtoCancelScheduleRequest,
        DtoCancelScheduleRequestTypedDict,
    )
    from .dto_cancelscheduleresponse import (
        DtoCancelScheduleResponse,
        DtoCancelScheduleResponseTypedDict,
    )
    from .dto_cancelsubscriptionrequest import (
        DtoCancelSubscriptionRequest,
        DtoCancelSubscriptionRequestTypedDict,
    )
    from .dto_cancelsubscriptionresponse import (
        DtoCancelSubscriptionResponse,
        DtoCancelSubscriptionResponseTypedDict,
    )
    from .dto_cloneplanrequest import DtoClonePlanRequest, DtoClonePlanRequestTypedDict
    from .dto_costanalyticitem import DtoCostAnalyticItem, DtoCostAnalyticItemTypedDict
    from .dto_costpoint import DtoCostPoint, DtoCostPointTypedDict
    from .dto_costsheetresponse import (
        DtoCostsheetResponse,
        DtoCostsheetResponseTypedDict,
    )
    from .dto_couponapplicationresponse import (
        DtoCouponApplicationResponse,
        DtoCouponApplicationResponseTypedDict,
    )
    from .dto_couponassociationresponse import (
        DtoCouponAssociationResponse,
        DtoCouponAssociationResponseTypedDict,
    )
    from .dto_couponresponse import DtoCouponResponse, DtoCouponResponseTypedDict
    from .dto_createaddonrequest import (
        DtoCreateAddonRequest,
        DtoCreateAddonRequestTypedDict,
    )
    from .dto_createaddonresponse import (
        DtoCreateAddonResponse,
        DtoCreateAddonResponseTypedDict,
    )
    from .dto_createapikeyrequest import (
        DtoCreateAPIKeyRequest,
        DtoCreateAPIKeyRequestTypedDict,
    )
    from .dto_createapikeyresponse import (
        DtoCreateAPIKeyResponse,
        DtoCreateAPIKeyResponseTypedDict,
    )
    from .dto_createbulkentitlementrequest import (
        DtoCreateBulkEntitlementRequest,
        DtoCreateBulkEntitlementRequestTypedDict,
    )
    from .dto_createbulkentitlementresponse import (
        DtoCreateBulkEntitlementResponse,
        DtoCreateBulkEntitlementResponseTypedDict,
    )
    from .dto_createbulkpricerequest import (
        DtoCreateBulkPriceRequest,
        DtoCreateBulkPriceRequestTypedDict,
    )
    from .dto_createbulkpriceresponse import (
        DtoCreateBulkPriceResponse,
        DtoCreateBulkPriceResponseTypedDict,
    )
    from .dto_createcostsheetrequest import (
        DtoCreateCostsheetRequest,
        DtoCreateCostsheetRequestTypedDict,
    )
    from .dto_createcostsheetresponse import (
        DtoCreateCostsheetResponse,
        DtoCreateCostsheetResponseTypedDict,
    )
    from .dto_createcouponrequest import (
        DtoCreateCouponRequest,
        DtoCreateCouponRequestTypedDict,
    )
    from .dto_createcreditgrantrequest import (
        DtoCreateCreditGrantRequest,
        DtoCreateCreditGrantRequestTypedDict,
    )
    from .dto_createcreditnotelineitemrequest import (
        DtoCreateCreditNoteLineItemRequest,
        DtoCreateCreditNoteLineItemRequestTypedDict,
    )
    from .dto_createcreditnoterequest import (
        DtoCreateCreditNoteRequest,
        DtoCreateCreditNoteRequestTypedDict,
    )
    from .dto_createcustomerrequest import (
        DtoCreateCustomerRequest,
        DtoCreateCustomerRequestTypedDict,
    )
    from .dto_createentitlementrequest import (
        DtoCreateEntitlementRequest,
        DtoCreateEntitlementRequestTypedDict,
    )
    from .dto_createentityintegrationmappingrequest import (
        DtoCreateEntityIntegrationMappingRequest,
        DtoCreateEntityIntegrationMappingRequestTypedDict,
    )
    from .dto_createenvironmentrequest import (
        DtoCreateEnvironmentRequest,
        DtoCreateEnvironmentRequestTypedDict,
    )
    from .dto_createfeaturerequest import (
        DtoCreateFeatureRequest,
        DtoCreateFeatureRequestTypedDict,
    )
    from .dto_creategrouprequest import (
        DtoCreateGroupRequest,
        DtoCreateGroupRequestTypedDict,
    )
    from .dto_createintegrationrequest import (
        DtoCreateIntegrationRequest,
        DtoCreateIntegrationRequestTypedDict,
    )
    from .dto_createinvoicelineitemrequest import (
        DtoCreateInvoiceLineItemRequest,
        DtoCreateInvoiceLineItemRequestTypedDict,
    )
    from .dto_createinvoicerequest import (
        DtoCreateInvoiceRequest,
        DtoCreateInvoiceRequestTypedDict,
    )
    from .dto_createmeterrequest import (
        DtoCreateMeterRequest,
        DtoCreateMeterRequestTypedDict,
    )
    from .dto_createpaymentrequest import (
        DtoCreatePaymentRequest,
        DtoCreatePaymentRequestTypedDict,
    )
    from .dto_createplanrequest import (
        DtoCreatePlanRequest,
        DtoCreatePlanRequestTypedDict,
    )
    from .dto_createpricerequest import (
        DtoCreatePriceRequest,
        DtoCreatePriceRequestTypedDict,
    )
    from .dto_createpricetier import DtoCreatePriceTier, DtoCreatePriceTierTypedDict
    from .dto_createpriceunitrequest import (
        DtoCreatePriceUnitRequest,
        DtoCreatePriceUnitRequestTypedDict,
    )
    from .dto_createpriceunitresponse import (
        DtoCreatePriceUnitResponse,
        DtoCreatePriceUnitResponseTypedDict,
    )
    from .dto_createscheduledtaskrequest import (
        DtoCreateScheduledTaskRequest,
        DtoCreateScheduledTaskRequestTypedDict,
    )
    from .dto_createsubscriptionlineitemrequest import (
        DtoCreateSubscriptionLineItemRequest,
        DtoCreateSubscriptionLineItemRequestTypedDict,
    )
    from .dto_createsubscriptionrequest import (
        DtoCreateSubscriptionRequest,
        DtoCreateSubscriptionRequestTypedDict,
    )
    from .dto_createtaskrequest import (
        DtoCreateTaskRequest,
        DtoCreateTaskRequestTypedDict,
    )
    from .dto_createtaxassociationrequest import (
        DtoCreateTaxAssociationRequest,
        DtoCreateTaxAssociationRequestTypedDict,
    )
    from .dto_createtaxraterequest import (
        DtoCreateTaxRateRequest,
        DtoCreateTaxRateRequestTypedDict,
    )
    from .dto_createuserrequest import (
        DtoCreateUserRequest,
        DtoCreateUserRequestTypedDict,
    )
    from .dto_createwalletrequest import (
        DtoCreateWalletRequest,
        DtoCreateWalletRequestTypedDict,
    )
    from .dto_creditgrantapplicationresponse import (
        DtoCreditGrantApplicationResponse,
        DtoCreditGrantApplicationResponseTypedDict,
    )
    from .dto_creditgrantresponse import (
        DtoCreditGrantResponse,
        DtoCreditGrantResponseTypedDict,
    )
    from .dto_creditnoteresponse import (
        DtoCreditNoteResponse,
        DtoCreditNoteResponseTypedDict,
    )
    from .dto_customanalyticitem import (
        DtoCustomAnalyticItem,
        DtoCustomAnalyticItemTypedDict,
    )
    from .dto_customerentitlementsresponse import (
        DtoCustomerEntitlementsResponse,
        DtoCustomerEntitlementsResponseTypedDict,
    )
    from .dto_customerinvoicesummary import (
        DtoCustomerInvoiceSummary,
        DtoCustomerInvoiceSummaryTypedDict,
    )
    from .dto_customerlookupresult import (
        DtoCustomerLookupResult,
        DtoCustomerLookupResultTypedDict,
    )
    from .dto_customermulticurrencyinvoicesummary import (
        DtoCustomerMultiCurrencyInvoiceSummary,
        DtoCustomerMultiCurrencyInvoiceSummaryTypedDict,
    )
    from .dto_customerresponse import DtoCustomerResponse, DtoCustomerResponseTypedDict
    from .dto_customerusagesummaryresponse import (
        DtoCustomerUsageSummaryResponse,
        DtoCustomerUsageSummaryResponseTypedDict,
    )
    from .dto_debugtracker import DtoDebugTracker, DtoDebugTrackerTypedDict
    from .dto_deletecostsheetresponse import (
        DtoDeleteCostsheetResponse,
        DtoDeleteCostsheetResponseTypedDict,
    )
    from .dto_deletecreditgrantrequest import (
        DtoDeleteCreditGrantRequest,
        DtoDeleteCreditGrantRequestTypedDict,
    )
    from .dto_deletepricerequest import (
        DtoDeletePriceRequest,
        DtoDeletePriceRequestTypedDict,
    )
    from .dto_deletesubscriptionlineitemrequest import (
        DtoDeleteSubscriptionLineItemRequest,
        DtoDeleteSubscriptionLineItemRequestTypedDict,
    )
    from .dto_entitlementsource import (
        DtoEntitlementSource,
        DtoEntitlementSourceTypedDict,
    )
    from .dto_entitlementsourceentitytype import DtoEntitlementSourceEntityType
    from .dto_entityintegrationmappingresponse import (
        DtoEntityIntegrationMappingResponse,
        DtoEntityIntegrationMappingResponseTypedDict,
    )
    from .dto_environmentresponse import (
        DtoEnvironmentResponse,
        DtoEnvironmentResponseTypedDict,
    )
    from .dto_event import DtoEvent, DtoEventTypedDict
    from .dto_eventcostinfo import DtoEventCostInfo, DtoEventCostInfoTypedDict
    from .dto_featureresponse import DtoFeatureResponse, DtoFeatureResponseTypedDict
    from .dto_featureusageinfo import DtoFeatureUsageInfo, DtoFeatureUsageInfoTypedDict
    from .dto_featureusagesummary import (
        DtoFeatureUsageSummary,
        DtoFeatureUsageSummaryTypedDict,
    )
    from .dto_getcostanalyticsrequest import (
        DtoGetCostAnalyticsRequest,
        DtoGetCostAnalyticsRequestTypedDict,
    )
    from .dto_getcostsheetresponse import (
        DtoGetCostsheetResponse,
        DtoGetCostsheetResponseTypedDict,
    )
    from .dto_getdetailedcostanalyticsresponse import (
        DtoGetDetailedCostAnalyticsResponse,
        DtoGetDetailedCostAnalyticsResponseTypedDict,
    )
    from .dto_geteventbyidresponse import (
        DtoGetEventByIDResponse,
        DtoGetEventByIDResponseTypedDict,
    )
    from .dto_geteventsrequest import DtoGetEventsRequest, DtoGetEventsRequestTypedDict
    from .dto_geteventsresponse import (
        DtoGetEventsResponse,
        DtoGetEventsResponseTypedDict,
    )
    from .dto_gethuggingfacebillingdataresponse import (
        DtoGetHuggingFaceBillingDataResponse,
        DtoGetHuggingFaceBillingDataResponseTypedDict,
    )
    from .dto_getpendingschedulesresponse import (
        DtoGetPendingSchedulesResponse,
        DtoGetPendingSchedulesResponseTypedDict,
    )
    from .dto_getpreviewinvoicerequest import (
        DtoGetPreviewInvoiceRequest,
        DtoGetPreviewInvoiceRequestTypedDict,
    )
    from .dto_getusageanalyticsrequest import (
        DtoGetUsageAnalyticsRequest,
        DtoGetUsageAnalyticsRequestTypedDict,
    )
    from .dto_getusageanalyticsresponse import (
        DtoGetUsageAnalyticsResponse,
        DtoGetUsageAnalyticsResponseTypedDict,
    )
    from .dto_getusagebymeterrequest import (
        DtoGetUsageByMeterRequest,
        DtoGetUsageByMeterRequestTypedDict,
    )
    from .dto_getusagebysubscriptionrequest import (
        DtoGetUsageBySubscriptionRequest,
        DtoGetUsageBySubscriptionRequestTypedDict,
    )
    from .dto_getusagebysubscriptionresponse import (
        DtoGetUsageBySubscriptionResponse,
        DtoGetUsageBySubscriptionResponseTypedDict,
    )
    from .dto_getusagerequest import DtoGetUsageRequest, DtoGetUsageRequestTypedDict
    from .dto_getusageresponse import DtoGetUsageResponse, DtoGetUsageResponseTypedDict
    from .dto_groupresponse import DtoGroupResponse, DtoGroupResponseTypedDict
    from .dto_ingesteventrequest import (
        DtoIngestEventRequest,
        DtoIngestEventRequestTypedDict,
    )
    from .dto_integrationentitymapping import (
        DtoIntegrationEntityMapping,
        DtoIntegrationEntityMappingTypedDict,
        Provider,
    )
    from .dto_invoicecoupon import DtoInvoiceCoupon, DtoInvoiceCouponTypedDict
    from .dto_invoicelineitemcoupon import (
        DtoInvoiceLineItemCoupon,
        DtoInvoiceLineItemCouponTypedDict,
    )
    from .dto_invoicelineitempreview import (
        DtoInvoiceLineItemPreview,
        DtoInvoiceLineItemPreviewTypedDict,
    )
    from .dto_invoicelineitemresponse import (
        DtoInvoiceLineItemResponse,
        DtoInvoiceLineItemResponseTypedDict,
    )
    from .dto_invoicepreview import DtoInvoicePreview, DtoInvoicePreviewTypedDict
    from .dto_lineitemcommitmentconfig import (
        DtoLineItemCommitmentConfig,
        DtoLineItemCommitmentConfigTypedDict,
    )
    from .dto_linkedintegrationsresponse import (
        DtoLinkedIntegrationsResponse,
        DtoLinkedIntegrationsResponseTypedDict,
    )
    from .dto_listaddonsresponse import (
        DtoListAddonsResponse,
        DtoListAddonsResponseTypedDict,
    )
    from .dto_listalertlogsresponse import (
        DtoListAlertLogsResponse,
        DtoListAlertLogsResponseTypedDict,
    )
    from .dto_listcostsheetresponse import (
        DtoListCostsheetResponse,
        DtoListCostsheetResponseTypedDict,
    )
    from .dto_listcouponsresponse import (
        DtoListCouponsResponse,
        DtoListCouponsResponseTypedDict,
    )
    from .dto_listcreditgrantapplicationsresponse import (
        DtoListCreditGrantApplicationsResponse,
        DtoListCreditGrantApplicationsResponseTypedDict,
    )
    from .dto_listcreditgrantsresponse import (
        DtoListCreditGrantsResponse,
        DtoListCreditGrantsResponseTypedDict,
    )
    from .dto_listcustomersresponse import (
        DtoListCustomersResponse,
        DtoListCustomersResponseTypedDict,
    )
    from .dto_listentitlementsresponse import (
        DtoListEntitlementsResponse,
        DtoListEntitlementsResponseTypedDict,
    )
    from .dto_listfeaturesresponse import (
        DtoListFeaturesResponse,
        DtoListFeaturesResponseTypedDict,
    )
    from .dto_listgroupsresponse import (
        DtoListGroupsResponse,
        DtoListGroupsResponseTypedDict,
    )
    from .dto_listinvoicesresponse import (
        DtoListInvoicesResponse,
        DtoListInvoicesResponseTypedDict,
    )
    from .dto_listpaymentsresponse import (
        DtoListPaymentsResponse,
        DtoListPaymentsResponseTypedDict,
    )
    from .dto_listplansresponse import (
        DtoListPlansResponse,
        DtoListPlansResponseTypedDict,
    )
    from .dto_listpricesresponse import (
        DtoListPricesResponse,
        DtoListPricesResponseTypedDict,
    )
    from .dto_listpriceunitsresponse import (
        DtoListPriceUnitsResponse,
        DtoListPriceUnitsResponseTypedDict,
    )
    from .dto_listscheduledtasksresponse import (
        DtoListScheduledTasksResponse,
        DtoListScheduledTasksResponseTypedDict,
    )
    from .dto_listsecretsresponse import (
        DtoListSecretsResponse,
        DtoListSecretsResponseTypedDict,
    )
    from .dto_listsubscriptionpausesresponse import (
        DtoListSubscriptionPausesResponse,
        DtoListSubscriptionPausesResponseTypedDict,
    )
    from .dto_listsubscriptionsresponse import (
        DtoListSubscriptionsResponse,
        DtoListSubscriptionsResponseTypedDict,
    )
    from .dto_listtasksresponse import (
        DtoListTasksResponse,
        DtoListTasksResponseTypedDict,
    )
    from .dto_listtaxassociationsresponse import (
        DtoListTaxAssociationsResponse,
        DtoListTaxAssociationsResponseTypedDict,
    )
    from .dto_listusersresponse import (
        DtoListUsersResponse,
        DtoListUsersResponseTypedDict,
    )
    from .dto_listwallettransactionsresponse import (
        DtoListWalletTransactionsResponse,
        DtoListWalletTransactionsResponseTypedDict,
    )
    from .dto_listworkflowsresponse import (
        DtoListWorkflowsResponse,
        DtoListWorkflowsResponseTypedDict,
    )
    from .dto_matchedmeter import DtoMatchedMeter, DtoMatchedMeterTypedDict
    from .dto_matchedprice import DtoMatchedPrice, DtoMatchedPriceTypedDict
    from .dto_matchedsubscriptionlineitem import (
        DtoMatchedSubscriptionLineItem,
        DtoMatchedSubscriptionLineItemTypedDict,
    )
    from .dto_metermatchingresult import (
        DtoMeterMatchingResult,
        DtoMeterMatchingResultTypedDict,
    )
    from .dto_meterresponse import DtoMeterResponse, DtoMeterResponseTypedDict
    from .dto_overrideentitlementrequest import (
        DtoOverrideEntitlementRequest,
        DtoOverrideEntitlementRequestTypedDict,
    )
    from .dto_overridelineitemrequest import (
        DtoOverrideLineItemRequest,
        DtoOverrideLineItemRequestTypedDict,
    )
    from .dto_pausesubscriptionrequest import (
        DtoPauseSubscriptionRequest,
        DtoPauseSubscriptionRequestTypedDict,
    )
    from .dto_paymentattemptresponse import (
        DtoPaymentAttemptResponse,
        DtoPaymentAttemptResponseTypedDict,
    )
    from .dto_paymentresponse import DtoPaymentResponse, DtoPaymentResponseTypedDict
    from .dto_plansummary import DtoPlanSummary, DtoPlanSummaryTypedDict
    from .dto_pricelookupresult import (
        DtoPriceLookupResult,
        DtoPriceLookupResultTypedDict,
    )
    from .dto_priceunitconfig import DtoPriceUnitConfig, DtoPriceUnitConfigTypedDict
    from .dto_priceunitresponse import (
        DtoPriceUnitResponse,
        DtoPriceUnitResponseTypedDict,
    )
    from .dto_prorationdetail import DtoProrationDetail, DtoProrationDetailTypedDict
    from .dto_prorationdetails import DtoProrationDetails, DtoProrationDetailsTypedDict
    from .dto_removeaddonrequest import (
        DtoRemoveAddonRequest,
        DtoRemoveAddonRequestTypedDict,
    )
    from .dto_resumesubscriptionrequest import (
        DtoResumeSubscriptionRequest,
        DtoResumeSubscriptionRequestTypedDict,
    )
    from .dto_scheduledtaskresponse import (
        DtoScheduledTaskResponse,
        DtoScheduledTaskResponseTypedDict,
    )
    from .dto_secretresponse import DtoSecretResponse, DtoSecretResponseTypedDict
    from .dto_sourceusageitem import DtoSourceUsageItem, DtoSourceUsageItemTypedDict
    from .dto_subscriptionchangeexecuteresponse import (
        DtoSubscriptionChangeExecuteResponse,
        DtoSubscriptionChangeExecuteResponseTypedDict,
    )
    from .dto_subscriptionchangepreviewresponse import (
        DtoSubscriptionChangePreviewResponse,
        DtoSubscriptionChangePreviewResponseTypedDict,
    )
    from .dto_subscriptionchangerequest import (
        DtoSubscriptionChangeRequest,
        DtoSubscriptionChangeRequestTypedDict,
    )
    from .dto_subscriptionentitlementsresponse import (
        DtoSubscriptionEntitlementsResponse,
        DtoSubscriptionEntitlementsResponseTypedDict,
    )
    from .dto_subscriptionlineitemlookupresult import (
        DtoSubscriptionLineItemLookupResult,
        DtoSubscriptionLineItemLookupResultTypedDict,
    )
    from .dto_subscriptionlineitemresponse import (
        DtoSubscriptionLineItemResponse,
        DtoSubscriptionLineItemResponseTypedDict,
    )
    from .dto_subscriptionpauseresponse import (
        DtoSubscriptionPauseResponse,
        DtoSubscriptionPauseResponseTypedDict,
    )
    from .dto_subscriptionphasecreaterequest import (
        DtoSubscriptionPhaseCreateRequest,
        DtoSubscriptionPhaseCreateRequestTypedDict,
    )
    from .dto_subscriptionphaseresponse import (
        DtoSubscriptionPhaseResponse,
        DtoSubscriptionPhaseResponseTypedDict,
    )
    from .dto_subscriptionpricecreaterequest import (
        DtoSubscriptionPriceCreateRequest,
        DtoSubscriptionPriceCreateRequestTypedDict,
    )
    from .dto_subscriptionresponsev2 import (
        DtoSubscriptionResponseV2,
        DtoSubscriptionResponseV2TypedDict,
    )
    from .dto_subscriptionscheduleresponse import (
        Configuration,
        ConfigurationTypedDict,
        DtoSubscriptionScheduleResponse,
        DtoSubscriptionScheduleResponseTypedDict,
        ExecutionResult,
        ExecutionResultTypedDict,
    )
    from .dto_subscriptionsummary import (
        DtoSubscriptionSummary,
        DtoSubscriptionSummaryTypedDict,
    )
    from .dto_subscriptionusagebymetersresponse import (
        DtoSubscriptionUsageByMetersResponse,
        DtoSubscriptionUsageByMetersResponseTypedDict,
    )
    from .dto_successresponse import DtoSuccessResponse, DtoSuccessResponseTypedDict
    from .dto_taskresponse import DtoTaskResponse, DtoTaskResponseTypedDict
    from .dto_taxappliedresponse import (
        DtoTaxAppliedResponse,
        DtoTaxAppliedResponseTypedDict,
    )
    from .dto_taxassociationresponse import (
        DtoTaxAssociationResponse,
        DtoTaxAssociationResponseTypedDict,
    )
    from .dto_taxassociationupdaterequest import (
        DtoTaxAssociationUpdateRequest,
        DtoTaxAssociationUpdateRequestTypedDict,
    )
    from .dto_taxrateoverride import DtoTaxRateOverride, DtoTaxRateOverrideTypedDict
    from .dto_taxrateresponse import DtoTaxRateResponse, DtoTaxRateResponseTypedDict
    from .dto_tenantbillingdetails import (
        DtoTenantBillingDetails,
        DtoTenantBillingDetailsTypedDict,
    )
    from .dto_tenantbillingusage import (
        DtoTenantBillingUsage,
        DtoTenantBillingUsageTypedDict,
    )
    from .dto_tenantresponse import DtoTenantResponse, DtoTenantResponseTypedDict
    from .dto_topupwalletrequest import (
        DtoTopUpWalletRequest,
        DtoTopUpWalletRequestTypedDict,
    )
    from .dto_topupwalletresponse import (
        DtoTopUpWalletResponse,
        DtoTopUpWalletResponseTypedDict,
    )
    from .dto_triggerforcerunrequest import (
        DtoTriggerForceRunRequest,
        DtoTriggerForceRunRequestTypedDict,
    )
    from .dto_triggerforcerunresponse import (
        DtoTriggerForceRunResponse,
        DtoTriggerForceRunResponseTypedDict,
    )
    from .dto_updateaddonrequest import (
        DtoUpdateAddonRequest,
        DtoUpdateAddonRequestTypedDict,
    )
    from .dto_updatecostsheetrequest import (
        DtoUpdateCostsheetRequest,
        DtoUpdateCostsheetRequestTypedDict,
    )
    from .dto_updatecostsheetresponse import (
        DtoUpdateCostsheetResponse,
        DtoUpdateCostsheetResponseTypedDict,
    )
    from .dto_updatecouponrequest import (
        DtoUpdateCouponRequest,
        DtoUpdateCouponRequestTypedDict,
    )
    from .dto_updatecreditgrantrequest import (
        DtoUpdateCreditGrantRequest,
        DtoUpdateCreditGrantRequestTypedDict,
    )
    from .dto_updatecustomerrequest import (
        DtoUpdateCustomerRequest,
        DtoUpdateCustomerRequestTypedDict,
    )
    from .dto_updateentitlementrequest import (
        DtoUpdateEntitlementRequest,
        DtoUpdateEntitlementRequestTypedDict,
    )
    from .dto_updateenvironmentrequest import (
        DtoUpdateEnvironmentRequest,
        DtoUpdateEnvironmentRequestTypedDict,
    )
    from .dto_updatefeaturerequest import (
        DtoUpdateFeatureRequest,
        DtoUpdateFeatureRequestTypedDict,
    )
    from .dto_updateinvoicerequest import (
        DtoUpdateInvoiceRequest,
        DtoUpdateInvoiceRequestTypedDict,
    )
    from .dto_updatepaymentrequest import (
        DtoUpdatePaymentRequest,
        DtoUpdatePaymentRequestTypedDict,
    )
    from .dto_updatepaymentstatusrequest import (
        DtoUpdatePaymentStatusRequest,
        DtoUpdatePaymentStatusRequestTypedDict,
    )
    from .dto_updateplanrequest import (
        DtoUpdatePlanRequest,
        DtoUpdatePlanRequestTypedDict,
    )
    from .dto_updatepricerequest import (
        DtoUpdatePriceRequest,
        DtoUpdatePriceRequestTypedDict,
    )
    from .dto_updatepriceunitrequest import (
        DtoUpdatePriceUnitRequest,
        DtoUpdatePriceUnitRequestTypedDict,
    )
    from .dto_updatescheduledtaskrequest import (
        DtoUpdateScheduledTaskRequest,
        DtoUpdateScheduledTaskRequestTypedDict,
    )
    from .dto_updatesubscriptionlineitemrequest import (
        DtoUpdateSubscriptionLineItemRequest,
        DtoUpdateSubscriptionLineItemRequestTypedDict,
    )
    from .dto_updatesubscriptionrequest import (
        DtoUpdateSubscriptionRequest,
        DtoUpdateSubscriptionRequestTypedDict,
    )
    from .dto_updatetaskstatusrequest import (
        DtoUpdateTaskStatusRequest,
        DtoUpdateTaskStatusRequestTypedDict,
    )
    from .dto_updatetaxraterequest import (
        DtoUpdateTaxRateRequest,
        DtoUpdateTaxRateRequestTypedDict,
    )
    from .dto_updatetenantrequest import (
        DtoUpdateTenantRequest,
        DtoUpdateTenantRequestTypedDict,
    )
    from .dto_updatewalletrequest import (
        DtoUpdateWalletRequest,
        DtoUpdateWalletRequestTypedDict,
    )
    from .dto_usageanalyticitem import (
        DtoUsageAnalyticItem,
        DtoUsageAnalyticItemTypedDict,
    )
    from .dto_usageanalyticpoint import (
        DtoUsageAnalyticPoint,
        DtoUsageAnalyticPointTypedDict,
    )
    from .dto_usagebreakdownitem import (
        DtoUsageBreakdownItem,
        DtoUsageBreakdownItemTypedDict,
    )
    from .dto_usageresult import DtoUsageResult, DtoUsageResultTypedDict
    from .dto_userresponse import DtoUserResponse, DtoUserResponseTypedDict
    from .dto_walletbalanceresponse import (
        DtoWalletBalanceResponse,
        DtoWalletBalanceResponseTypedDict,
    )
    from .dto_walletresponse import DtoWalletResponse, DtoWalletResponseTypedDict
    from .dto_wallettransactionresponse import (
        DtoWalletTransactionResponse,
        DtoWalletTransactionResponseTypedDict,
    )
    from .dto_workflowexecutiondto import (
        DTOWorkflowExecutionDTO,
        DTOWorkflowExecutionDTOTypedDict,
    )
    from .entitlemententitytype import EntitlementEntityType
    from .entitlementfilter import (
        EntitlementFilter,
        EntitlementFilterOrder,
        EntitlementFilterTypedDict,
    )
    from .entitlementusageresetperiod import EntitlementUsageResetPeriod
    from .entitytype import EntityType
    from .errors_errordetail import ErrorsErrorDetail, ErrorsErrorDetailTypedDict
    from .errors_errorresponse import ErrorsErrorResponse, ErrorsErrorResponseTypedDict
    from .eventprocessingstatustype import EventProcessingStatusType
    from .failurepoint import FailurePoint, FailurePointTypedDict
    from .failurepointtype import FailurePointType
    from .featurefilter import FeatureFilter, FeatureFilterOrder, FeatureFilterTypedDict
    from .featuretype import FeatureType
    from .filetype import FileType
    from .filtercondition import FilterCondition, FilterConditionTypedDict
    from .filteroperatortype import FilterOperatorType
    from .github_com_flexprice_flexprice_internal_domain_addon_addon import (
        GithubComFlexpriceFlexpriceInternalDomainAddonAddon,
        GithubComFlexpriceFlexpriceInternalDomainAddonAddonTypedDict,
    )
    from .github_com_flexprice_flexprice_internal_domain_coupon_coupon import (
        GithubComFlexpriceFlexpriceInternalDomainCouponCoupon,
        GithubComFlexpriceFlexpriceInternalDomainCouponCouponTypedDict,
    )
    from .github_com_flexprice_flexprice_internal_domain_customer_customer import (
        GithubComFlexpriceFlexpriceInternalDomainCustomerCustomer,
        GithubComFlexpriceFlexpriceInternalDomainCustomerCustomerTypedDict,
    )
    from .github_com_flexprice_flexprice_internal_domain_feature_feature import (
        GithubComFlexpriceFlexpriceInternalDomainFeatureFeature,
        GithubComFlexpriceFlexpriceInternalDomainFeatureFeatureTypedDict,
    )
    from .github_com_flexprice_flexprice_internal_domain_plan_plan import (
        GithubComFlexpriceFlexpriceInternalDomainPlanPlan,
        GithubComFlexpriceFlexpriceInternalDomainPlanPlanTypedDict,
    )
    from .github_com_flexprice_flexprice_internal_types_value import (
        GithubComFlexpriceFlexpriceInternalTypesValue,
        GithubComFlexpriceFlexpriceInternalTypesValueTypedDict,
    )
    from .groupfilter import GroupFilter, GroupFilterOrder, GroupFilterTypedDict
    from .integrationentitytype import IntegrationEntityType
    from .invoicebilling import InvoiceBilling
    from .invoicebillingreason import InvoiceBillingReason
    from .invoicecadence import InvoiceCadence
    from .invoicefilter import InvoiceFilter, InvoiceFilterOrder, InvoiceFilterTypedDict
    from .invoicestatus import InvoiceStatus
    from .invoicetype import InvoiceType
    from .listresponse_dto_walletresponse import (
        ListResponseDtoWalletResponse,
        ListResponseDtoWalletResponseTypedDict,
    )
    from .meter_aggregation import MeterAggregation, MeterAggregationTypedDict
    from .meter_filter import MeterFilter, MeterFilterTypedDict
    from .meter_meter import MeterMeter, MeterMeterTypedDict
    from .models_temporalworkflowresult import (
        ModelsTemporalWorkflowResult,
        ModelsTemporalWorkflowResultTypedDict,
    )
    from .paginationresponse import PaginationResponse, PaginationResponseTypedDict
    from .pausemode import PauseMode
    from .pausestatus import PauseStatus
    from .paymentbehavior import PaymentBehavior
    from .paymentdestinationtype import PaymentDestinationType
    from .paymentgatewaytype import PaymentGatewayType
    from .paymentmethodtype import PaymentMethodType
    from .paymentstatus import PaymentStatus
    from .paymentterms import PaymentTerms
    from .planfilter import PlanFilter, PlanFilterOrder, PlanFilterTypedDict
    from .price_jsonbtransformquantity import (
        PriceJSONBTransformQuantity,
        PriceJSONBTransformQuantityTypedDict,
    )
    from .price_price import PricePrice, PricePriceTypedDict
    from .price_pricetier import PricePriceTier, PricePriceTierTypedDict
    from .price_transformquantity import (
        PriceTransformQuantity,
        PriceTransformQuantityTypedDict,
    )
    from .priceentitytype import PriceEntityType
    from .pricefilter import PriceFilter, PriceFilterOrder, PriceFilterTypedDict
    from .pricetype import PriceType
    from .priceunitfilter import (
        PriceUnitFilter,
        PriceUnitFilterOrder,
        PriceUnitFilterTypedDict,
    )
    from .priceunittype import PriceUnitType
    from .prorationbehavior import ProrationBehavior
    from .queryfilter import QueryFilter, QueryFilterOrder, QueryFilterTypedDict
    from .resetusage import ResetUsage
    from .resumemode import ResumeMode
    from .roundtype import RoundType
    from .s3compressiontype import S3CompressionType
    from .s3encryptiontype import S3EncryptionType
    from .s3jobconfig import S3JobConfig, S3JobConfigTypedDict
    from .scheduledtaskentitytype import ScheduledTaskEntityType
    from .scheduledtaskinterval import ScheduledTaskInterval
    from .schedulestatus import ScheduleStatus
    from .scheduletype import ScheduleType
    from .secretprovider import SecretProvider
    from .secrettype import SecretType
    from .security import Security, SecurityTypedDict
    from .sortcondition import SortCondition, SortConditionTypedDict
    from .sortdirection import SortDirection
    from .status import Status
    from .subscription_subscriptionlineitem import (
        SubscriptionSubscriptionLineItem,
        SubscriptionSubscriptionLineItemTypedDict,
    )
    from .subscription_subscriptionpause import (
        SubscriptionSubscriptionPause,
        SubscriptionSubscriptionPauseTypedDict,
    )
    from .subscriptionchangetype import SubscriptionChangeType
    from .subscriptionfilter import (
        SubscriptionFilter,
        SubscriptionFilterOrder,
        SubscriptionFilterTypedDict,
    )
    from .subscriptionlineitementitytype import SubscriptionLineItemEntityType
    from .subscriptionschedulechangetype import SubscriptionScheduleChangeType
    from .subscriptionstatus import SubscriptionStatus
    from .taskstatus import TaskStatus
    from .tasktype import TaskType
    from .taxrateentitytype import TaxRateEntityType
    from .taxratescope import TaxRateScope
    from .taxratestatus import TaxRateStatus
    from .taxratetype import TaxRateType
    from .timerangefilter import TimeRangeFilter, TimeRangeFilterTypedDict
    from .transactionreason import TransactionReason
    from .transactionstatus import TransactionStatus
    from .transactiontype import TransactionType
    from .userfilter import UserFilter, UserFilterOrder, UserFilterTypedDict
    from .usertype import UserType
    from .walletconfig import WalletConfig, WalletConfigTypedDict
    from .walletconfigpricetype import WalletConfigPriceType
    from .walletfilter import WalletFilter, WalletFilterOrder, WalletFilterTypedDict
    from .walletstatus import WalletStatus
    from .wallettransactionfilter import (
        WalletTransactionFilter,
        WalletTransactionFilterOrder,
        WalletTransactionFilterTypedDict,
    )
    from .wallettxreferencetype import WalletTxReferenceType
    from .wallettype import WalletType
    from .windowsize import WindowSize
    from .workflowexecutionfilter import (
        WorkflowExecutionFilter,
        WorkflowExecutionFilterOrder,
        WorkflowExecutionFilterTypedDict,
    )  # Pydantic models with forward references
DtoPriceResponse.model_rebuild()
DtoPlanResponse.model_rebuild()
DtoEntitlementResponse.model_rebuild()
DtoAddonResponse.model_rebuild()
DtoSubscriptionResponse.model_rebuild()
DtoInvoiceResponse.model_rebuild()


__all__ = [
    "AddonAssociationEntityType",
    "AddonFilter",
    "AddonFilterOrder",
    "AddonFilterTypedDict",
    "AddonStatus",
    "AddonType",
    "AggregationType",
    "AlertCondition",
    "AlertEntityType",
    "AlertInfo",
    "AlertInfoTypedDict",
    "AlertLogFilter",
    "AlertLogFilterOrder",
    "AlertLogFilterTypedDict",
    "AlertSettings",
    "AlertSettingsTypedDict",
    "AlertState",
    "AlertThreshold",
    "AlertThresholdTypedDict",
    "AlertType",
    "ApplicationStatus",
    "AutoTopup",
    "AutoTopupTypedDict",
    "BillingCadence",
    "BillingCycle",
    "BillingModel",
    "BillingPeriod",
    "BillingTier",
    "CancelImmediatelyInvoicePolicy",
    "CancellationType",
    "CollectionMethod",
    "CommitmentInfo",
    "CommitmentInfoTypedDict",
    "CommitmentType",
    "Configuration",
    "ConfigurationTypedDict",
    "CostsheetFilter",
    "CostsheetFilterTypedDict",
    "CouponCadence",
    "CouponFilter",
    "CouponFilterOrder",
    "CouponFilterTypedDict",
    "CouponType",
    "CreditBreakdown",
    "CreditBreakdownTypedDict",
    "CreditGrantApplicationReason",
    "CreditGrantCadence",
    "CreditGrantExpiryDurationUnit",
    "CreditGrantExpiryType",
    "CreditGrantPeriod",
    "CreditGrantScope",
    "CreditNoteReason",
    "CreditNoteStatus",
    "CreditNoteType",
    "CreditnoteCreditNoteLineItem",
    "CreditnoteCreditNoteLineItemTypedDict",
    "CustomerFilter",
    "CustomerFilterOrder",
    "CustomerFilterTypedDict",
    "DTOWorkflowExecutionDTO",
    "DTOWorkflowExecutionDTOTypedDict",
    "DataType",
    "DebugTrackerStatus",
    "DtoActivateDraftSubscriptionRequest",
    "DtoActivateDraftSubscriptionRequestTypedDict",
    "DtoAddAddonRequest",
    "DtoAddAddonRequestTypedDict",
    "DtoAddAddonToSubscriptionRequest",
    "DtoAddAddonToSubscriptionRequestTypedDict",
    "DtoAddonAssociationResponse",
    "DtoAddonAssociationResponseTypedDict",
    "DtoAddonResponse",
    "DtoAddonResponseTypedDict",
    "DtoAddress",
    "DtoAddressTypedDict",
    "DtoAggregatedEntitlement",
    "DtoAggregatedEntitlementTypedDict",
    "DtoAggregatedFeature",
    "DtoAggregatedFeatureTypedDict",
    "DtoAlertLogResponse",
    "DtoAlertLogResponseTypedDict",
    "DtoBillingCycleInfo",
    "DtoBillingCycleInfoTypedDict",
    "DtoBillingPeriodInfo",
    "DtoBillingPeriodInfoTypedDict",
    "DtoBulkIngestEventRequest",
    "DtoBulkIngestEventRequestTypedDict",
    "DtoCancelScheduleRequest",
    "DtoCancelScheduleRequestTypedDict",
    "DtoCancelScheduleResponse",
    "DtoCancelScheduleResponseTypedDict",
    "DtoCancelSubscriptionRequest",
    "DtoCancelSubscriptionRequestTypedDict",
    "DtoCancelSubscriptionResponse",
    "DtoCancelSubscriptionResponseTypedDict",
    "DtoClonePlanRequest",
    "DtoClonePlanRequestTypedDict",
    "DtoCostAnalyticItem",
    "DtoCostAnalyticItemTypedDict",
    "DtoCostPoint",
    "DtoCostPointTypedDict",
    "DtoCostsheetResponse",
    "DtoCostsheetResponseTypedDict",
    "DtoCouponApplicationResponse",
    "DtoCouponApplicationResponseTypedDict",
    "DtoCouponAssociationResponse",
    "DtoCouponAssociationResponseTypedDict",
    "DtoCouponResponse",
    "DtoCouponResponseTypedDict",
    "DtoCreateAPIKeyRequest",
    "DtoCreateAPIKeyRequestTypedDict",
    "DtoCreateAPIKeyResponse",
    "DtoCreateAPIKeyResponseTypedDict",
    "DtoCreateAddonRequest",
    "DtoCreateAddonRequestTypedDict",
    "DtoCreateAddonResponse",
    "DtoCreateAddonResponseTypedDict",
    "DtoCreateBulkEntitlementRequest",
    "DtoCreateBulkEntitlementRequestTypedDict",
    "DtoCreateBulkEntitlementResponse",
    "DtoCreateBulkEntitlementResponseTypedDict",
    "DtoCreateBulkPriceRequest",
    "DtoCreateBulkPriceRequestTypedDict",
    "DtoCreateBulkPriceResponse",
    "DtoCreateBulkPriceResponseTypedDict",
    "DtoCreateCostsheetRequest",
    "DtoCreateCostsheetRequestTypedDict",
    "DtoCreateCostsheetResponse",
    "DtoCreateCostsheetResponseTypedDict",
    "DtoCreateCouponRequest",
    "DtoCreateCouponRequestTypedDict",
    "DtoCreateCreditGrantRequest",
    "DtoCreateCreditGrantRequestTypedDict",
    "DtoCreateCreditNoteLineItemRequest",
    "DtoCreateCreditNoteLineItemRequestTypedDict",
    "DtoCreateCreditNoteRequest",
    "DtoCreateCreditNoteRequestTypedDict",
    "DtoCreateCustomerRequest",
    "DtoCreateCustomerRequestTypedDict",
    "DtoCreateEntitlementRequest",
    "DtoCreateEntitlementRequestTypedDict",
    "DtoCreateEntityIntegrationMappingRequest",
    "DtoCreateEntityIntegrationMappingRequestTypedDict",
    "DtoCreateEnvironmentRequest",
    "DtoCreateEnvironmentRequestTypedDict",
    "DtoCreateFeatureRequest",
    "DtoCreateFeatureRequestTypedDict",
    "DtoCreateGroupRequest",
    "DtoCreateGroupRequestTypedDict",
    "DtoCreateIntegrationRequest",
    "DtoCreateIntegrationRequestTypedDict",
    "DtoCreateInvoiceLineItemRequest",
    "DtoCreateInvoiceLineItemRequestTypedDict",
    "DtoCreateInvoiceRequest",
    "DtoCreateInvoiceRequestTypedDict",
    "DtoCreateMeterRequest",
    "DtoCreateMeterRequestTypedDict",
    "DtoCreatePaymentRequest",
    "DtoCreatePaymentRequestTypedDict",
    "DtoCreatePlanRequest",
    "DtoCreatePlanRequestTypedDict",
    "DtoCreatePriceRequest",
    "DtoCreatePriceRequestTypedDict",
    "DtoCreatePriceTier",
    "DtoCreatePriceTierTypedDict",
    "DtoCreatePriceUnitRequest",
    "DtoCreatePriceUnitRequestTypedDict",
    "DtoCreatePriceUnitResponse",
    "DtoCreatePriceUnitResponseTypedDict",
    "DtoCreateScheduledTaskRequest",
    "DtoCreateScheduledTaskRequestTypedDict",
    "DtoCreateSubscriptionLineItemRequest",
    "DtoCreateSubscriptionLineItemRequestTypedDict",
    "DtoCreateSubscriptionRequest",
    "DtoCreateSubscriptionRequestTypedDict",
    "DtoCreateTaskRequest",
    "DtoCreateTaskRequestTypedDict",
    "DtoCreateTaxAssociationRequest",
    "DtoCreateTaxAssociationRequestTypedDict",
    "DtoCreateTaxRateRequest",
    "DtoCreateTaxRateRequestTypedDict",
    "DtoCreateUserRequest",
    "DtoCreateUserRequestTypedDict",
    "DtoCreateWalletRequest",
    "DtoCreateWalletRequestTypedDict",
    "DtoCreditGrantApplicationResponse",
    "DtoCreditGrantApplicationResponseTypedDict",
    "DtoCreditGrantResponse",
    "DtoCreditGrantResponseTypedDict",
    "DtoCreditNoteResponse",
    "DtoCreditNoteResponseTypedDict",
    "DtoCustomAnalyticItem",
    "DtoCustomAnalyticItemTypedDict",
    "DtoCustomerEntitlementsResponse",
    "DtoCustomerEntitlementsResponseTypedDict",
    "DtoCustomerInvoiceSummary",
    "DtoCustomerInvoiceSummaryTypedDict",
    "DtoCustomerLookupResult",
    "DtoCustomerLookupResultTypedDict",
    "DtoCustomerMultiCurrencyInvoiceSummary",
    "DtoCustomerMultiCurrencyInvoiceSummaryTypedDict",
    "DtoCustomerResponse",
    "DtoCustomerResponseTypedDict",
    "DtoCustomerUsageSummaryResponse",
    "DtoCustomerUsageSummaryResponseTypedDict",
    "DtoDebugTracker",
    "DtoDebugTrackerTypedDict",
    "DtoDeleteCostsheetResponse",
    "DtoDeleteCostsheetResponseTypedDict",
    "DtoDeleteCreditGrantRequest",
    "DtoDeleteCreditGrantRequestTypedDict",
    "DtoDeletePriceRequest",
    "DtoDeletePriceRequestTypedDict",
    "DtoDeleteSubscriptionLineItemRequest",
    "DtoDeleteSubscriptionLineItemRequestTypedDict",
    "DtoEntitlementResponse",
    "DtoEntitlementResponseTypedDict",
    "DtoEntitlementSource",
    "DtoEntitlementSourceEntityType",
    "DtoEntitlementSourceTypedDict",
    "DtoEntityIntegrationMappingResponse",
    "DtoEntityIntegrationMappingResponseTypedDict",
    "DtoEnvironmentResponse",
    "DtoEnvironmentResponseTypedDict",
    "DtoEvent",
    "DtoEventCostInfo",
    "DtoEventCostInfoTypedDict",
    "DtoEventTypedDict",
    "DtoFeatureResponse",
    "DtoFeatureResponseTypedDict",
    "DtoFeatureUsageInfo",
    "DtoFeatureUsageInfoTypedDict",
    "DtoFeatureUsageSummary",
    "DtoFeatureUsageSummaryTypedDict",
    "DtoGetCostAnalyticsRequest",
    "DtoGetCostAnalyticsRequestTypedDict",
    "DtoGetCostsheetResponse",
    "DtoGetCostsheetResponseTypedDict",
    "DtoGetDetailedCostAnalyticsResponse",
    "DtoGetDetailedCostAnalyticsResponseTypedDict",
    "DtoGetEventByIDResponse",
    "DtoGetEventByIDResponseTypedDict",
    "DtoGetEventsRequest",
    "DtoGetEventsRequestTypedDict",
    "DtoGetEventsResponse",
    "DtoGetEventsResponseTypedDict",
    "DtoGetHuggingFaceBillingDataResponse",
    "DtoGetHuggingFaceBillingDataResponseTypedDict",
    "DtoGetPendingSchedulesResponse",
    "DtoGetPendingSchedulesResponseTypedDict",
    "DtoGetPreviewInvoiceRequest",
    "DtoGetPreviewInvoiceRequestTypedDict",
    "DtoGetUsageAnalyticsRequest",
    "DtoGetUsageAnalyticsRequestTypedDict",
    "DtoGetUsageAnalyticsResponse",
    "DtoGetUsageAnalyticsResponseTypedDict",
    "DtoGetUsageByMeterRequest",
    "DtoGetUsageByMeterRequestTypedDict",
    "DtoGetUsageBySubscriptionRequest",
    "DtoGetUsageBySubscriptionRequestTypedDict",
    "DtoGetUsageBySubscriptionResponse",
    "DtoGetUsageBySubscriptionResponseTypedDict",
    "DtoGetUsageRequest",
    "DtoGetUsageRequestTypedDict",
    "DtoGetUsageResponse",
    "DtoGetUsageResponseTypedDict",
    "DtoGroupResponse",
    "DtoGroupResponseTypedDict",
    "DtoIngestEventRequest",
    "DtoIngestEventRequestTypedDict",
    "DtoIntegrationEntityMapping",
    "DtoIntegrationEntityMappingTypedDict",
    "DtoInvoiceCoupon",
    "DtoInvoiceCouponTypedDict",
    "DtoInvoiceLineItemCoupon",
    "DtoInvoiceLineItemCouponTypedDict",
    "DtoInvoiceLineItemPreview",
    "DtoInvoiceLineItemPreviewTypedDict",
    "DtoInvoiceLineItemResponse",
    "DtoInvoiceLineItemResponseTypedDict",
    "DtoInvoicePreview",
    "DtoInvoicePreviewTypedDict",
    "DtoInvoiceResponse",
    "DtoInvoiceResponseTypedDict",
    "DtoLineItemCommitmentConfig",
    "DtoLineItemCommitmentConfigTypedDict",
    "DtoLinkedIntegrationsResponse",
    "DtoLinkedIntegrationsResponseTypedDict",
    "DtoListAddonsResponse",
    "DtoListAddonsResponseTypedDict",
    "DtoListAlertLogsResponse",
    "DtoListAlertLogsResponseTypedDict",
    "DtoListCostsheetResponse",
    "DtoListCostsheetResponseTypedDict",
    "DtoListCouponsResponse",
    "DtoListCouponsResponseTypedDict",
    "DtoListCreditGrantApplicationsResponse",
    "DtoListCreditGrantApplicationsResponseTypedDict",
    "DtoListCreditGrantsResponse",
    "DtoListCreditGrantsResponseTypedDict",
    "DtoListCustomersResponse",
    "DtoListCustomersResponseTypedDict",
    "DtoListEntitlementsResponse",
    "DtoListEntitlementsResponseTypedDict",
    "DtoListFeaturesResponse",
    "DtoListFeaturesResponseTypedDict",
    "DtoListGroupsResponse",
    "DtoListGroupsResponseTypedDict",
    "DtoListInvoicesResponse",
    "DtoListInvoicesResponseTypedDict",
    "DtoListPaymentsResponse",
    "DtoListPaymentsResponseTypedDict",
    "DtoListPlansResponse",
    "DtoListPlansResponseTypedDict",
    "DtoListPriceUnitsResponse",
    "DtoListPriceUnitsResponseTypedDict",
    "DtoListPricesResponse",
    "DtoListPricesResponseTypedDict",
    "DtoListScheduledTasksResponse",
    "DtoListScheduledTasksResponseTypedDict",
    "DtoListSecretsResponse",
    "DtoListSecretsResponseTypedDict",
    "DtoListSubscriptionPausesResponse",
    "DtoListSubscriptionPausesResponseTypedDict",
    "DtoListSubscriptionsResponse",
    "DtoListSubscriptionsResponseTypedDict",
    "DtoListTasksResponse",
    "DtoListTasksResponseTypedDict",
    "DtoListTaxAssociationsResponse",
    "DtoListTaxAssociationsResponseTypedDict",
    "DtoListUsersResponse",
    "DtoListUsersResponseTypedDict",
    "DtoListWalletTransactionsResponse",
    "DtoListWalletTransactionsResponseTypedDict",
    "DtoListWorkflowsResponse",
    "DtoListWorkflowsResponseTypedDict",
    "DtoMatchedMeter",
    "DtoMatchedMeterTypedDict",
    "DtoMatchedPrice",
    "DtoMatchedPriceTypedDict",
    "DtoMatchedSubscriptionLineItem",
    "DtoMatchedSubscriptionLineItemTypedDict",
    "DtoMeterMatchingResult",
    "DtoMeterMatchingResultTypedDict",
    "DtoMeterResponse",
    "DtoMeterResponseTypedDict",
    "DtoOverrideEntitlementRequest",
    "DtoOverrideEntitlementRequestTypedDict",
    "DtoOverrideLineItemRequest",
    "DtoOverrideLineItemRequestTypedDict",
    "DtoPauseSubscriptionRequest",
    "DtoPauseSubscriptionRequestTypedDict",
    "DtoPaymentAttemptResponse",
    "DtoPaymentAttemptResponseTypedDict",
    "DtoPaymentResponse",
    "DtoPaymentResponseTypedDict",
    "DtoPlanResponse",
    "DtoPlanResponseTypedDict",
    "DtoPlanSummary",
    "DtoPlanSummaryTypedDict",
    "DtoPriceLookupResult",
    "DtoPriceLookupResultTypedDict",
    "DtoPriceResponse",
    "DtoPriceResponseTypedDict",
    "DtoPriceUnitConfig",
    "DtoPriceUnitConfigTypedDict",
    "DtoPriceUnitResponse",
    "DtoPriceUnitResponseTypedDict",
    "DtoProrationDetail",
    "DtoProrationDetailTypedDict",
    "DtoProrationDetails",
    "DtoProrationDetailsTypedDict",
    "DtoRemoveAddonRequest",
    "DtoRemoveAddonRequestTypedDict",
    "DtoResumeSubscriptionRequest",
    "DtoResumeSubscriptionRequestTypedDict",
    "DtoScheduledTaskResponse",
    "DtoScheduledTaskResponseTypedDict",
    "DtoSecretResponse",
    "DtoSecretResponseTypedDict",
    "DtoSourceUsageItem",
    "DtoSourceUsageItemTypedDict",
    "DtoSubscriptionChangeExecuteResponse",
    "DtoSubscriptionChangeExecuteResponseTypedDict",
    "DtoSubscriptionChangePreviewResponse",
    "DtoSubscriptionChangePreviewResponseTypedDict",
    "DtoSubscriptionChangeRequest",
    "DtoSubscriptionChangeRequestTypedDict",
    "DtoSubscriptionEntitlementsResponse",
    "DtoSubscriptionEntitlementsResponseTypedDict",
    "DtoSubscriptionLineItemLookupResult",
    "DtoSubscriptionLineItemLookupResultTypedDict",
    "DtoSubscriptionLineItemResponse",
    "DtoSubscriptionLineItemResponseTypedDict",
    "DtoSubscriptionPauseResponse",
    "DtoSubscriptionPauseResponseTypedDict",
    "DtoSubscriptionPhaseCreateRequest",
    "DtoSubscriptionPhaseCreateRequestTypedDict",
    "DtoSubscriptionPhaseResponse",
    "DtoSubscriptionPhaseResponseTypedDict",
    "DtoSubscriptionPriceCreateRequest",
    "DtoSubscriptionPriceCreateRequestTypedDict",
    "DtoSubscriptionResponse",
    "DtoSubscriptionResponseTypedDict",
    "DtoSubscriptionResponseV2",
    "DtoSubscriptionResponseV2TypedDict",
    "DtoSubscriptionScheduleResponse",
    "DtoSubscriptionScheduleResponseTypedDict",
    "DtoSubscriptionSummary",
    "DtoSubscriptionSummaryTypedDict",
    "DtoSubscriptionUsageByMetersResponse",
    "DtoSubscriptionUsageByMetersResponseTypedDict",
    "DtoSuccessResponse",
    "DtoSuccessResponseTypedDict",
    "DtoTaskResponse",
    "DtoTaskResponseTypedDict",
    "DtoTaxAppliedResponse",
    "DtoTaxAppliedResponseTypedDict",
    "DtoTaxAssociationResponse",
    "DtoTaxAssociationResponseTypedDict",
    "DtoTaxAssociationUpdateRequest",
    "DtoTaxAssociationUpdateRequestTypedDict",
    "DtoTaxRateOverride",
    "DtoTaxRateOverrideTypedDict",
    "DtoTaxRateResponse",
    "DtoTaxRateResponseTypedDict",
    "DtoTenantBillingDetails",
    "DtoTenantBillingDetailsTypedDict",
    "DtoTenantBillingUsage",
    "DtoTenantBillingUsageTypedDict",
    "DtoTenantResponse",
    "DtoTenantResponseTypedDict",
    "DtoTopUpWalletRequest",
    "DtoTopUpWalletRequestTypedDict",
    "DtoTopUpWalletResponse",
    "DtoTopUpWalletResponseTypedDict",
    "DtoTriggerForceRunRequest",
    "DtoTriggerForceRunRequestTypedDict",
    "DtoTriggerForceRunResponse",
    "DtoTriggerForceRunResponseTypedDict",
    "DtoUpdateAddonRequest",
    "DtoUpdateAddonRequestTypedDict",
    "DtoUpdateCostsheetRequest",
    "DtoUpdateCostsheetRequestTypedDict",
    "DtoUpdateCostsheetResponse",
    "DtoUpdateCostsheetResponseTypedDict",
    "DtoUpdateCouponRequest",
    "DtoUpdateCouponRequestTypedDict",
    "DtoUpdateCreditGrantRequest",
    "DtoUpdateCreditGrantRequestTypedDict",
    "DtoUpdateCustomerRequest",
    "DtoUpdateCustomerRequestTypedDict",
    "DtoUpdateEntitlementRequest",
    "DtoUpdateEntitlementRequestTypedDict",
    "DtoUpdateEnvironmentRequest",
    "DtoUpdateEnvironmentRequestTypedDict",
    "DtoUpdateFeatureRequest",
    "DtoUpdateFeatureRequestTypedDict",
    "DtoUpdateInvoiceRequest",
    "DtoUpdateInvoiceRequestTypedDict",
    "DtoUpdatePaymentRequest",
    "DtoUpdatePaymentRequestTypedDict",
    "DtoUpdatePaymentStatusRequest",
    "DtoUpdatePaymentStatusRequestTypedDict",
    "DtoUpdatePlanRequest",
    "DtoUpdatePlanRequestTypedDict",
    "DtoUpdatePriceRequest",
    "DtoUpdatePriceRequestTypedDict",
    "DtoUpdatePriceUnitRequest",
    "DtoUpdatePriceUnitRequestTypedDict",
    "DtoUpdateScheduledTaskRequest",
    "DtoUpdateScheduledTaskRequestTypedDict",
    "DtoUpdateSubscriptionLineItemRequest",
    "DtoUpdateSubscriptionLineItemRequestTypedDict",
    "DtoUpdateSubscriptionRequest",
    "DtoUpdateSubscriptionRequestTypedDict",
    "DtoUpdateTaskStatusRequest",
    "DtoUpdateTaskStatusRequestTypedDict",
    "DtoUpdateTaxRateRequest",
    "DtoUpdateTaxRateRequestTypedDict",
    "DtoUpdateTenantRequest",
    "DtoUpdateTenantRequestTypedDict",
    "DtoUpdateWalletRequest",
    "DtoUpdateWalletRequestTypedDict",
    "DtoUsageAnalyticItem",
    "DtoUsageAnalyticItemTypedDict",
    "DtoUsageAnalyticPoint",
    "DtoUsageAnalyticPointTypedDict",
    "DtoUsageBreakdownItem",
    "DtoUsageBreakdownItemTypedDict",
    "DtoUsageResult",
    "DtoUsageResultTypedDict",
    "DtoUserResponse",
    "DtoUserResponseTypedDict",
    "DtoWalletBalanceResponse",
    "DtoWalletBalanceResponseTypedDict",
    "DtoWalletResponse",
    "DtoWalletResponseTypedDict",
    "DtoWalletTransactionResponse",
    "DtoWalletTransactionResponseTypedDict",
    "EntitlementEntityType",
    "EntitlementFilter",
    "EntitlementFilterOrder",
    "EntitlementFilterTypedDict",
    "EntitlementUsageResetPeriod",
    "EntityType",
    "ErrorsErrorDetail",
    "ErrorsErrorDetailTypedDict",
    "ErrorsErrorResponse",
    "ErrorsErrorResponseTypedDict",
    "EventProcessingStatusType",
    "ExecutionResult",
    "ExecutionResultTypedDict",
    "FailurePoint",
    "FailurePointType",
    "FailurePointTypedDict",
    "FeatureFilter",
    "FeatureFilterOrder",
    "FeatureFilterTypedDict",
    "FeatureType",
    "FileType",
    "FilterCondition",
    "FilterConditionTypedDict",
    "FilterOperatorType",
    "GithubComFlexpriceFlexpriceInternalDomainAddonAddon",
    "GithubComFlexpriceFlexpriceInternalDomainAddonAddonTypedDict",
    "GithubComFlexpriceFlexpriceInternalDomainCouponCoupon",
    "GithubComFlexpriceFlexpriceInternalDomainCouponCouponTypedDict",
    "GithubComFlexpriceFlexpriceInternalDomainCustomerCustomer",
    "GithubComFlexpriceFlexpriceInternalDomainCustomerCustomerTypedDict",
    "GithubComFlexpriceFlexpriceInternalDomainFeatureFeature",
    "GithubComFlexpriceFlexpriceInternalDomainFeatureFeatureTypedDict",
    "GithubComFlexpriceFlexpriceInternalDomainPlanPlan",
    "GithubComFlexpriceFlexpriceInternalDomainPlanPlanTypedDict",
    "GithubComFlexpriceFlexpriceInternalTypesValue",
    "GithubComFlexpriceFlexpriceInternalTypesValueTypedDict",
    "GroupFilter",
    "GroupFilterOrder",
    "GroupFilterTypedDict",
    "IntegrationEntityType",
    "InvoiceBilling",
    "InvoiceBillingReason",
    "InvoiceCadence",
    "InvoiceFilter",
    "InvoiceFilterOrder",
    "InvoiceFilterTypedDict",
    "InvoiceStatus",
    "InvoiceType",
    "ListResponseDtoWalletResponse",
    "ListResponseDtoWalletResponseTypedDict",
    "MeterAggregation",
    "MeterAggregationTypedDict",
    "MeterFilter",
    "MeterFilterTypedDict",
    "MeterMeter",
    "MeterMeterTypedDict",
    "ModelsTemporalWorkflowResult",
    "ModelsTemporalWorkflowResultTypedDict",
    "PaginationResponse",
    "PaginationResponseTypedDict",
    "PauseMode",
    "PauseStatus",
    "PaymentBehavior",
    "PaymentDestinationType",
    "PaymentGatewayType",
    "PaymentMethodType",
    "PaymentStatus",
    "PaymentTerms",
    "PlanFilter",
    "PlanFilterOrder",
    "PlanFilterTypedDict",
    "PriceEntityType",
    "PriceFilter",
    "PriceFilterOrder",
    "PriceFilterTypedDict",
    "PriceJSONBTransformQuantity",
    "PriceJSONBTransformQuantityTypedDict",
    "PricePrice",
    "PricePriceTier",
    "PricePriceTierTypedDict",
    "PricePriceTypedDict",
    "PriceTransformQuantity",
    "PriceTransformQuantityTypedDict",
    "PriceType",
    "PriceUnitFilter",
    "PriceUnitFilterOrder",
    "PriceUnitFilterTypedDict",
    "PriceUnitType",
    "ProrationBehavior",
    "Provider",
    "QueryFilter",
    "QueryFilterOrder",
    "QueryFilterTypedDict",
    "ResetUsage",
    "ResumeMode",
    "RoundType",
    "S3CompressionType",
    "S3EncryptionType",
    "S3JobConfig",
    "S3JobConfigTypedDict",
    "ScheduleStatus",
    "ScheduleType",
    "ScheduledTaskEntityType",
    "ScheduledTaskInterval",
    "SecretProvider",
    "SecretType",
    "Security",
    "SecurityTypedDict",
    "SortCondition",
    "SortConditionTypedDict",
    "SortDirection",
    "Status",
    "SubscriptionChangeType",
    "SubscriptionFilter",
    "SubscriptionFilterOrder",
    "SubscriptionFilterTypedDict",
    "SubscriptionLineItemEntityType",
    "SubscriptionScheduleChangeType",
    "SubscriptionStatus",
    "SubscriptionSubscriptionLineItem",
    "SubscriptionSubscriptionLineItemTypedDict",
    "SubscriptionSubscriptionPause",
    "SubscriptionSubscriptionPauseTypedDict",
    "TaskStatus",
    "TaskType",
    "TaxRateEntityType",
    "TaxRateScope",
    "TaxRateStatus",
    "TaxRateType",
    "TimeRangeFilter",
    "TimeRangeFilterTypedDict",
    "TransactionReason",
    "TransactionStatus",
    "TransactionType",
    "UserFilter",
    "UserFilterOrder",
    "UserFilterTypedDict",
    "UserType",
    "WalletConfig",
    "WalletConfigPriceType",
    "WalletConfigTypedDict",
    "WalletFilter",
    "WalletFilterOrder",
    "WalletFilterTypedDict",
    "WalletStatus",
    "WalletTransactionFilter",
    "WalletTransactionFilterOrder",
    "WalletTransactionFilterTypedDict",
    "WalletTxReferenceType",
    "WalletType",
    "WindowSize",
    "WorkflowExecutionFilter",
    "WorkflowExecutionFilterOrder",
    "WorkflowExecutionFilterTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AddonAssociationEntityType": ".addonassociationentitytype",
    "AddonFilter": ".addonfilter",
    "AddonFilterOrder": ".addonfilter",
    "AddonFilterTypedDict": ".addonfilter",
    "AddonStatus": ".addonstatus",
    "AddonType": ".addontype",
    "AggregationType": ".aggregationtype",
    "AlertCondition": ".alertcondition",
    "AlertEntityType": ".alertentitytype",
    "AlertInfo": ".alertinfo",
    "AlertInfoTypedDict": ".alertinfo",
    "AlertLogFilter": ".alertlogfilter",
    "AlertLogFilterOrder": ".alertlogfilter",
    "AlertLogFilterTypedDict": ".alertlogfilter",
    "AlertSettings": ".alertsettings",
    "AlertSettingsTypedDict": ".alertsettings",
    "AlertState": ".alertstate",
    "AlertThreshold": ".alertthreshold",
    "AlertThresholdTypedDict": ".alertthreshold",
    "AlertType": ".alerttype",
    "ApplicationStatus": ".applicationstatus",
    "AutoTopup": ".autotopup",
    "AutoTopupTypedDict": ".autotopup",
    "BillingCadence": ".billingcadence",
    "BillingCycle": ".billingcycle",
    "BillingModel": ".billingmodel",
    "BillingPeriod": ".billingperiod",
    "BillingTier": ".billingtier",
    "CancelImmediatelyInvoicePolicy": ".cancelimmediatelyinvoicepolicy",
    "CancellationType": ".cancellationtype",
    "CollectionMethod": ".collectionmethod",
    "CommitmentInfo": ".commitmentinfo",
    "CommitmentInfoTypedDict": ".commitmentinfo",
    "CommitmentType": ".commitmenttype",
    "CostsheetFilter": ".costsheet_filter",
    "CostsheetFilterTypedDict": ".costsheet_filter",
    "CouponCadence": ".couponcadence",
    "CouponFilter": ".couponfilter",
    "CouponFilterOrder": ".couponfilter",
    "CouponFilterTypedDict": ".couponfilter",
    "CouponType": ".coupontype",
    "CreditBreakdown": ".creditbreakdown",
    "CreditBreakdownTypedDict": ".creditbreakdown",
    "CreditGrantApplicationReason": ".creditgrantapplicationreason",
    "CreditGrantCadence": ".creditgrantcadence",
    "CreditGrantExpiryDurationUnit": ".creditgrantexpirydurationunit",
    "CreditGrantExpiryType": ".creditgrantexpirytype",
    "CreditGrantPeriod": ".creditgrantperiod",
    "CreditGrantScope": ".creditgrantscope",
    "CreditnoteCreditNoteLineItem": ".creditnote_creditnotelineitem",
    "CreditnoteCreditNoteLineItemTypedDict": ".creditnote_creditnotelineitem",
    "CreditNoteReason": ".creditnotereason",
    "CreditNoteStatus": ".creditnotestatus",
    "CreditNoteType": ".creditnotetype",
    "CustomerFilter": ".customerfilter",
    "CustomerFilterOrder": ".customerfilter",
    "CustomerFilterTypedDict": ".customerfilter",
    "DataType": ".datatype",
    "DebugTrackerStatus": ".debugtrackerstatus",
    "DtoActivateDraftSubscriptionRequest": ".dto_activatedraftsubscriptionrequest",
    "DtoActivateDraftSubscriptionRequestTypedDict": ".dto_activatedraftsubscriptionrequest",
    "DtoAddAddonRequest": ".dto_addaddonrequest",
    "DtoAddAddonRequestTypedDict": ".dto_addaddonrequest",
    "DtoAddAddonToSubscriptionRequest": ".dto_addaddontosubscriptionrequest",
    "DtoAddAddonToSubscriptionRequestTypedDict": ".dto_addaddontosubscriptionrequest",
    "DtoAddonAssociationResponse": ".dto_addonassociationresponse",
    "DtoAddonAssociationResponseTypedDict": ".dto_addonassociationresponse",
    "DtoAddress": ".dto_address",
    "DtoAddressTypedDict": ".dto_address",
    "DtoAggregatedEntitlement": ".dto_aggregatedentitlement",
    "DtoAggregatedEntitlementTypedDict": ".dto_aggregatedentitlement",
    "DtoAggregatedFeature": ".dto_aggregatedfeature",
    "DtoAggregatedFeatureTypedDict": ".dto_aggregatedfeature",
    "DtoAlertLogResponse": ".dto_alertlogresponse",
    "DtoAlertLogResponseTypedDict": ".dto_alertlogresponse",
    "DtoBillingCycleInfo": ".dto_billingcycleinfo",
    "DtoBillingCycleInfoTypedDict": ".dto_billingcycleinfo",
    "DtoBillingPeriodInfo": ".dto_billingperiodinfo",
    "DtoBillingPeriodInfoTypedDict": ".dto_billingperiodinfo",
    "DtoBulkIngestEventRequest": ".dto_bulkingesteventrequest",
    "DtoBulkIngestEventRequestTypedDict": ".dto_bulkingesteventrequest",
    "DtoCancelScheduleRequest": ".dto_cancelschedulerequest",
    "DtoCancelScheduleRequestTypedDict": ".dto_cancelschedulerequest",
    "DtoCancelScheduleResponse": ".dto_cancelscheduleresponse",
    "DtoCancelScheduleResponseTypedDict": ".dto_cancelscheduleresponse",
    "DtoCancelSubscriptionRequest": ".dto_cancelsubscriptionrequest",
    "DtoCancelSubscriptionRequestTypedDict": ".dto_cancelsubscriptionrequest",
    "DtoCancelSubscriptionResponse": ".dto_cancelsubscriptionresponse",
    "DtoCancelSubscriptionResponseTypedDict": ".dto_cancelsubscriptionresponse",
    "DtoClonePlanRequest": ".dto_cloneplanrequest",
    "DtoClonePlanRequestTypedDict": ".dto_cloneplanrequest",
    "DtoCostAnalyticItem": ".dto_costanalyticitem",
    "DtoCostAnalyticItemTypedDict": ".dto_costanalyticitem",
    "DtoCostPoint": ".dto_costpoint",
    "DtoCostPointTypedDict": ".dto_costpoint",
    "DtoCostsheetResponse": ".dto_costsheetresponse",
    "DtoCostsheetResponseTypedDict": ".dto_costsheetresponse",
    "DtoCouponApplicationResponse": ".dto_couponapplicationresponse",
    "DtoCouponApplicationResponseTypedDict": ".dto_couponapplicationresponse",
    "DtoCouponAssociationResponse": ".dto_couponassociationresponse",
    "DtoCouponAssociationResponseTypedDict": ".dto_couponassociationresponse",
    "DtoCouponResponse": ".dto_couponresponse",
    "DtoCouponResponseTypedDict": ".dto_couponresponse",
    "DtoCreateAddonRequest": ".dto_createaddonrequest",
    "DtoCreateAddonRequestTypedDict": ".dto_createaddonrequest",
    "DtoCreateAddonResponse": ".dto_createaddonresponse",
    "DtoCreateAddonResponseTypedDict": ".dto_createaddonresponse",
    "DtoCreateAPIKeyRequest": ".dto_createapikeyrequest",
    "DtoCreateAPIKeyRequestTypedDict": ".dto_createapikeyrequest",
    "DtoCreateAPIKeyResponse": ".dto_createapikeyresponse",
    "DtoCreateAPIKeyResponseTypedDict": ".dto_createapikeyresponse",
    "DtoCreateBulkEntitlementRequest": ".dto_createbulkentitlementrequest",
    "DtoCreateBulkEntitlementRequestTypedDict": ".dto_createbulkentitlementrequest",
    "DtoCreateBulkEntitlementResponse": ".dto_createbulkentitlementresponse",
    "DtoCreateBulkEntitlementResponseTypedDict": ".dto_createbulkentitlementresponse",
    "DtoCreateBulkPriceRequest": ".dto_createbulkpricerequest",
    "DtoCreateBulkPriceRequestTypedDict": ".dto_createbulkpricerequest",
    "DtoCreateBulkPriceResponse": ".dto_createbulkpriceresponse",
    "DtoCreateBulkPriceResponseTypedDict": ".dto_createbulkpriceresponse",
    "DtoCreateCostsheetRequest": ".dto_createcostsheetrequest",
    "DtoCreateCostsheetRequestTypedDict": ".dto_createcostsheetrequest",
    "DtoCreateCostsheetResponse": ".dto_createcostsheetresponse",
    "DtoCreateCostsheetResponseTypedDict": ".dto_createcostsheetresponse",
    "DtoCreateCouponRequest": ".dto_createcouponrequest",
    "DtoCreateCouponRequestTypedDict": ".dto_createcouponrequest",
    "DtoCreateCreditGrantRequest": ".dto_createcreditgrantrequest",
    "DtoCreateCreditGrantRequestTypedDict": ".dto_createcreditgrantrequest",
    "DtoCreateCreditNoteLineItemRequest": ".dto_createcreditnotelineitemrequest",
    "DtoCreateCreditNoteLineItemRequestTypedDict": ".dto_createcreditnotelineitemrequest",
    "DtoCreateCreditNoteRequest": ".dto_createcreditnoterequest",
    "DtoCreateCreditNoteRequestTypedDict": ".dto_createcreditnoterequest",
    "DtoCreateCustomerRequest": ".dto_createcustomerrequest",
    "DtoCreateCustomerRequestTypedDict": ".dto_createcustomerrequest",
    "DtoCreateEntitlementRequest": ".dto_createentitlementrequest",
    "DtoCreateEntitlementRequestTypedDict": ".dto_createentitlementrequest",
    "DtoCreateEntityIntegrationMappingRequest": ".dto_createentityintegrationmappingrequest",
    "DtoCreateEntityIntegrationMappingRequestTypedDict": ".dto_createentityintegrationmappingrequest",
    "DtoCreateEnvironmentRequest": ".dto_createenvironmentrequest",
    "DtoCreateEnvironmentRequestTypedDict": ".dto_createenvironmentrequest",
    "DtoCreateFeatureRequest": ".dto_createfeaturerequest",
    "DtoCreateFeatureRequestTypedDict": ".dto_createfeaturerequest",
    "DtoCreateGroupRequest": ".dto_creategrouprequest",
    "DtoCreateGroupRequestTypedDict": ".dto_creategrouprequest",
    "DtoCreateIntegrationRequest": ".dto_createintegrationrequest",
    "DtoCreateIntegrationRequestTypedDict": ".dto_createintegrationrequest",
    "DtoCreateInvoiceLineItemRequest": ".dto_createinvoicelineitemrequest",
    "DtoCreateInvoiceLineItemRequestTypedDict": ".dto_createinvoicelineitemrequest",
    "DtoCreateInvoiceRequest": ".dto_createinvoicerequest",
    "DtoCreateInvoiceRequestTypedDict": ".dto_createinvoicerequest",
    "DtoCreateMeterRequest": ".dto_createmeterrequest",
    "DtoCreateMeterRequestTypedDict": ".dto_createmeterrequest",
    "DtoCreatePaymentRequest": ".dto_createpaymentrequest",
    "DtoCreatePaymentRequestTypedDict": ".dto_createpaymentrequest",
    "DtoCreatePlanRequest": ".dto_createplanrequest",
    "DtoCreatePlanRequestTypedDict": ".dto_createplanrequest",
    "DtoCreatePriceRequest": ".dto_createpricerequest",
    "DtoCreatePriceRequestTypedDict": ".dto_createpricerequest",
    "DtoCreatePriceTier": ".dto_createpricetier",
    "DtoCreatePriceTierTypedDict": ".dto_createpricetier",
    "DtoCreatePriceUnitRequest": ".dto_createpriceunitrequest",
    "DtoCreatePriceUnitRequestTypedDict": ".dto_createpriceunitrequest",
    "DtoCreatePriceUnitResponse": ".dto_createpriceunitresponse",
    "DtoCreatePriceUnitResponseTypedDict": ".dto_createpriceunitresponse",
    "DtoCreateScheduledTaskRequest": ".dto_createscheduledtaskrequest",
    "DtoCreateScheduledTaskRequestTypedDict": ".dto_createscheduledtaskrequest",
    "DtoCreateSubscriptionLineItemRequest": ".dto_createsubscriptionlineitemrequest",
    "DtoCreateSubscriptionLineItemRequestTypedDict": ".dto_createsubscriptionlineitemrequest",
    "DtoCreateSubscriptionRequest": ".dto_createsubscriptionrequest",
    "DtoCreateSubscriptionRequestTypedDict": ".dto_createsubscriptionrequest",
    "DtoCreateTaskRequest": ".dto_createtaskrequest",
    "DtoCreateTaskRequestTypedDict": ".dto_createtaskrequest",
    "DtoCreateTaxAssociationRequest": ".dto_createtaxassociationrequest",
    "DtoCreateTaxAssociationRequestTypedDict": ".dto_createtaxassociationrequest",
    "DtoCreateTaxRateRequest": ".dto_createtaxraterequest",
    "DtoCreateTaxRateRequestTypedDict": ".dto_createtaxraterequest",
    "DtoCreateUserRequest": ".dto_createuserrequest",
    "DtoCreateUserRequestTypedDict": ".dto_createuserrequest",
    "DtoCreateWalletRequest": ".dto_createwalletrequest",
    "DtoCreateWalletRequestTypedDict": ".dto_createwalletrequest",
    "DtoCreditGrantApplicationResponse": ".dto_creditgrantapplicationresponse",
    "DtoCreditGrantApplicationResponseTypedDict": ".dto_creditgrantapplicationresponse",
    "DtoCreditGrantResponse": ".dto_creditgrantresponse",
    "DtoCreditGrantResponseTypedDict": ".dto_creditgrantresponse",
    "DtoCreditNoteResponse": ".dto_creditnoteresponse",
    "DtoCreditNoteResponseTypedDict": ".dto_creditnoteresponse",
    "DtoCustomAnalyticItem": ".dto_customanalyticitem",
    "DtoCustomAnalyticItemTypedDict": ".dto_customanalyticitem",
    "DtoCustomerEntitlementsResponse": ".dto_customerentitlementsresponse",
    "DtoCustomerEntitlementsResponseTypedDict": ".dto_customerentitlementsresponse",
    "DtoCustomerInvoiceSummary": ".dto_customerinvoicesummary",
    "DtoCustomerInvoiceSummaryTypedDict": ".dto_customerinvoicesummary",
    "DtoCustomerLookupResult": ".dto_customerlookupresult",
    "DtoCustomerLookupResultTypedDict": ".dto_customerlookupresult",
    "DtoCustomerMultiCurrencyInvoiceSummary": ".dto_customermulticurrencyinvoicesummary",
    "DtoCustomerMultiCurrencyInvoiceSummaryTypedDict": ".dto_customermulticurrencyinvoicesummary",
    "DtoCustomerResponse": ".dto_customerresponse",
    "DtoCustomerResponseTypedDict": ".dto_customerresponse",
    "DtoCustomerUsageSummaryResponse": ".dto_customerusagesummaryresponse",
    "DtoCustomerUsageSummaryResponseTypedDict": ".dto_customerusagesummaryresponse",
    "DtoDebugTracker": ".dto_debugtracker",
    "DtoDebugTrackerTypedDict": ".dto_debugtracker",
    "DtoDeleteCostsheetResponse": ".dto_deletecostsheetresponse",
    "DtoDeleteCostsheetResponseTypedDict": ".dto_deletecostsheetresponse",
    "DtoDeleteCreditGrantRequest": ".dto_deletecreditgrantrequest",
    "DtoDeleteCreditGrantRequestTypedDict": ".dto_deletecreditgrantrequest",
    "DtoDeletePriceRequest": ".dto_deletepricerequest",
    "DtoDeletePriceRequestTypedDict": ".dto_deletepricerequest",
    "DtoDeleteSubscriptionLineItemRequest": ".dto_deletesubscriptionlineitemrequest",
    "DtoDeleteSubscriptionLineItemRequestTypedDict": ".dto_deletesubscriptionlineitemrequest",
    "DtoEntitlementSource": ".dto_entitlementsource",
    "DtoEntitlementSourceTypedDict": ".dto_entitlementsource",
    "DtoEntitlementSourceEntityType": ".dto_entitlementsourceentitytype",
    "DtoEntityIntegrationMappingResponse": ".dto_entityintegrationmappingresponse",
    "DtoEntityIntegrationMappingResponseTypedDict": ".dto_entityintegrationmappingresponse",
    "DtoEnvironmentResponse": ".dto_environmentresponse",
    "DtoEnvironmentResponseTypedDict": ".dto_environmentresponse",
    "DtoEvent": ".dto_event",
    "DtoEventTypedDict": ".dto_event",
    "DtoEventCostInfo": ".dto_eventcostinfo",
    "DtoEventCostInfoTypedDict": ".dto_eventcostinfo",
    "DtoFeatureResponse": ".dto_featureresponse",
    "DtoFeatureResponseTypedDict": ".dto_featureresponse",
    "DtoFeatureUsageInfo": ".dto_featureusageinfo",
    "DtoFeatureUsageInfoTypedDict": ".dto_featureusageinfo",
    "DtoFeatureUsageSummary": ".dto_featureusagesummary",
    "DtoFeatureUsageSummaryTypedDict": ".dto_featureusagesummary",
    "DtoGetCostAnalyticsRequest": ".dto_getcostanalyticsrequest",
    "DtoGetCostAnalyticsRequestTypedDict": ".dto_getcostanalyticsrequest",
    "DtoGetCostsheetResponse": ".dto_getcostsheetresponse",
    "DtoGetCostsheetResponseTypedDict": ".dto_getcostsheetresponse",
    "DtoGetDetailedCostAnalyticsResponse": ".dto_getdetailedcostanalyticsresponse",
    "DtoGetDetailedCostAnalyticsResponseTypedDict": ".dto_getdetailedcostanalyticsresponse",
    "DtoGetEventByIDResponse": ".dto_geteventbyidresponse",
    "DtoGetEventByIDResponseTypedDict": ".dto_geteventbyidresponse",
    "DtoGetEventsRequest": ".dto_geteventsrequest",
    "DtoGetEventsRequestTypedDict": ".dto_geteventsrequest",
    "DtoGetEventsResponse": ".dto_geteventsresponse",
    "DtoGetEventsResponseTypedDict": ".dto_geteventsresponse",
    "DtoGetHuggingFaceBillingDataResponse": ".dto_gethuggingfacebillingdataresponse",
    "DtoGetHuggingFaceBillingDataResponseTypedDict": ".dto_gethuggingfacebillingdataresponse",
    "DtoGetPendingSchedulesResponse": ".dto_getpendingschedulesresponse",
    "DtoGetPendingSchedulesResponseTypedDict": ".dto_getpendingschedulesresponse",
    "DtoGetPreviewInvoiceRequest": ".dto_getpreviewinvoicerequest",
    "DtoGetPreviewInvoiceRequestTypedDict": ".dto_getpreviewinvoicerequest",
    "DtoGetUsageAnalyticsRequest": ".dto_getusageanalyticsrequest",
    "DtoGetUsageAnalyticsRequestTypedDict": ".dto_getusageanalyticsrequest",
    "DtoGetUsageAnalyticsResponse": ".dto_getusageanalyticsresponse",
    "DtoGetUsageAnalyticsResponseTypedDict": ".dto_getusageanalyticsresponse",
    "DtoGetUsageByMeterRequest": ".dto_getusagebymeterrequest",
    "DtoGetUsageByMeterRequestTypedDict": ".dto_getusagebymeterrequest",
    "DtoGetUsageBySubscriptionRequest": ".dto_getusagebysubscriptionrequest",
    "DtoGetUsageBySubscriptionRequestTypedDict": ".dto_getusagebysubscriptionrequest",
    "DtoGetUsageBySubscriptionResponse": ".dto_getusagebysubscriptionresponse",
    "DtoGetUsageBySubscriptionResponseTypedDict": ".dto_getusagebysubscriptionresponse",
    "DtoGetUsageRequest": ".dto_getusagerequest",
    "DtoGetUsageRequestTypedDict": ".dto_getusagerequest",
    "DtoGetUsageResponse": ".dto_getusageresponse",
    "DtoGetUsageResponseTypedDict": ".dto_getusageresponse",
    "DtoGroupResponse": ".dto_groupresponse",
    "DtoGroupResponseTypedDict": ".dto_groupresponse",
    "DtoIngestEventRequest": ".dto_ingesteventrequest",
    "DtoIngestEventRequestTypedDict": ".dto_ingesteventrequest",
    "DtoIntegrationEntityMapping": ".dto_integrationentitymapping",
    "DtoIntegrationEntityMappingTypedDict": ".dto_integrationentitymapping",
    "Provider": ".dto_integrationentitymapping",
    "DtoInvoiceCoupon": ".dto_invoicecoupon",
    "DtoInvoiceCouponTypedDict": ".dto_invoicecoupon",
    "DtoInvoiceLineItemCoupon": ".dto_invoicelineitemcoupon",
    "DtoInvoiceLineItemCouponTypedDict": ".dto_invoicelineitemcoupon",
    "DtoInvoiceLineItemPreview": ".dto_invoicelineitempreview",
    "DtoInvoiceLineItemPreviewTypedDict": ".dto_invoicelineitempreview",
    "DtoInvoiceLineItemResponse": ".dto_invoicelineitemresponse",
    "DtoInvoiceLineItemResponseTypedDict": ".dto_invoicelineitemresponse",
    "DtoInvoicePreview": ".dto_invoicepreview",
    "DtoInvoicePreviewTypedDict": ".dto_invoicepreview",
    "DtoLineItemCommitmentConfig": ".dto_lineitemcommitmentconfig",
    "DtoLineItemCommitmentConfigTypedDict": ".dto_lineitemcommitmentconfig",
    "DtoLinkedIntegrationsResponse": ".dto_linkedintegrationsresponse",
    "DtoLinkedIntegrationsResponseTypedDict": ".dto_linkedintegrationsresponse",
    "DtoListAddonsResponse": ".dto_listaddonsresponse",
    "DtoListAddonsResponseTypedDict": ".dto_listaddonsresponse",
    "DtoListAlertLogsResponse": ".dto_listalertlogsresponse",
    "DtoListAlertLogsResponseTypedDict": ".dto_listalertlogsresponse",
    "DtoListCostsheetResponse": ".dto_listcostsheetresponse",
    "DtoListCostsheetResponseTypedDict": ".dto_listcostsheetresponse",
    "DtoListCouponsResponse": ".dto_listcouponsresponse",
    "DtoListCouponsResponseTypedDict": ".dto_listcouponsresponse",
    "DtoListCreditGrantApplicationsResponse": ".dto_listcreditgrantapplicationsresponse",
    "DtoListCreditGrantApplicationsResponseTypedDict": ".dto_listcreditgrantapplicationsresponse",
    "DtoListCreditGrantsResponse": ".dto_listcreditgrantsresponse",
    "DtoListCreditGrantsResponseTypedDict": ".dto_listcreditgrantsresponse",
    "DtoListCustomersResponse": ".dto_listcustomersresponse",
    "DtoListCustomersResponseTypedDict": ".dto_listcustomersresponse",
    "DtoListEntitlementsResponse": ".dto_listentitlementsresponse",
    "DtoListEntitlementsResponseTypedDict": ".dto_listentitlementsresponse",
    "DtoListFeaturesResponse": ".dto_listfeaturesresponse",
    "DtoListFeaturesResponseTypedDict": ".dto_listfeaturesresponse",
    "DtoListGroupsResponse": ".dto_listgroupsresponse",
    "DtoListGroupsResponseTypedDict": ".dto_listgroupsresponse",
    "DtoListInvoicesResponse": ".dto_listinvoicesresponse",
    "DtoListInvoicesResponseTypedDict": ".dto_listinvoicesresponse",
    "DtoListPaymentsResponse": ".dto_listpaymentsresponse",
    "DtoListPaymentsResponseTypedDict": ".dto_listpaymentsresponse",
    "DtoListPlansResponse": ".dto_listplansresponse",
    "DtoListPlansResponseTypedDict": ".dto_listplansresponse",
    "DtoListPricesResponse": ".dto_listpricesresponse",
    "DtoListPricesResponseTypedDict": ".dto_listpricesresponse",
    "DtoListPriceUnitsResponse": ".dto_listpriceunitsresponse",
    "DtoListPriceUnitsResponseTypedDict": ".dto_listpriceunitsresponse",
    "DtoListScheduledTasksResponse": ".dto_listscheduledtasksresponse",
    "DtoListScheduledTasksResponseTypedDict": ".dto_listscheduledtasksresponse",
    "DtoListSecretsResponse": ".dto_listsecretsresponse",
    "DtoListSecretsResponseTypedDict": ".dto_listsecretsresponse",
    "DtoListSubscriptionPausesResponse": ".dto_listsubscriptionpausesresponse",
    "DtoListSubscriptionPausesResponseTypedDict": ".dto_listsubscriptionpausesresponse",
    "DtoListSubscriptionsResponse": ".dto_listsubscriptionsresponse",
    "DtoListSubscriptionsResponseTypedDict": ".dto_listsubscriptionsresponse",
    "DtoListTasksResponse": ".dto_listtasksresponse",
    "DtoListTasksResponseTypedDict": ".dto_listtasksresponse",
    "DtoListTaxAssociationsResponse": ".dto_listtaxassociationsresponse",
    "DtoListTaxAssociationsResponseTypedDict": ".dto_listtaxassociationsresponse",
    "DtoListUsersResponse": ".dto_listusersresponse",
    "DtoListUsersResponseTypedDict": ".dto_listusersresponse",
    "DtoListWalletTransactionsResponse": ".dto_listwallettransactionsresponse",
    "DtoListWalletTransactionsResponseTypedDict": ".dto_listwallettransactionsresponse",
    "DtoListWorkflowsResponse": ".dto_listworkflowsresponse",
    "DtoListWorkflowsResponseTypedDict": ".dto_listworkflowsresponse",
    "DtoMatchedMeter": ".dto_matchedmeter",
    "DtoMatchedMeterTypedDict": ".dto_matchedmeter",
    "DtoMatchedPrice": ".dto_matchedprice",
    "DtoMatchedPriceTypedDict": ".dto_matchedprice",
    "DtoMatchedSubscriptionLineItem": ".dto_matchedsubscriptionlineitem",
    "DtoMatchedSubscriptionLineItemTypedDict": ".dto_matchedsubscriptionlineitem",
    "DtoMeterMatchingResult": ".dto_metermatchingresult",
    "DtoMeterMatchingResultTypedDict": ".dto_metermatchingresult",
    "DtoMeterResponse": ".dto_meterresponse",
    "DtoMeterResponseTypedDict": ".dto_meterresponse",
    "DtoOverrideEntitlementRequest": ".dto_overrideentitlementrequest",
    "DtoOverrideEntitlementRequestTypedDict": ".dto_overrideentitlementrequest",
    "DtoOverrideLineItemRequest": ".dto_overridelineitemrequest",
    "DtoOverrideLineItemRequestTypedDict": ".dto_overridelineitemrequest",
    "DtoPauseSubscriptionRequest": ".dto_pausesubscriptionrequest",
    "DtoPauseSubscriptionRequestTypedDict": ".dto_pausesubscriptionrequest",
    "DtoPaymentAttemptResponse": ".dto_paymentattemptresponse",
    "DtoPaymentAttemptResponseTypedDict": ".dto_paymentattemptresponse",
    "DtoPaymentResponse": ".dto_paymentresponse",
    "DtoPaymentResponseTypedDict": ".dto_paymentresponse",
    "DtoPlanSummary": ".dto_plansummary",
    "DtoPlanSummaryTypedDict": ".dto_plansummary",
    "DtoPriceLookupResult": ".dto_pricelookupresult",
    "DtoPriceLookupResultTypedDict": ".dto_pricelookupresult",
    "DtoPriceUnitConfig": ".dto_priceunitconfig",
    "DtoPriceUnitConfigTypedDict": ".dto_priceunitconfig",
    "DtoPriceUnitResponse": ".dto_priceunitresponse",
    "DtoPriceUnitResponseTypedDict": ".dto_priceunitresponse",
    "DtoProrationDetail": ".dto_prorationdetail",
    "DtoProrationDetailTypedDict": ".dto_prorationdetail",
    "DtoProrationDetails": ".dto_prorationdetails",
    "DtoProrationDetailsTypedDict": ".dto_prorationdetails",
    "DtoRemoveAddonRequest": ".dto_removeaddonrequest",
    "DtoRemoveAddonRequestTypedDict": ".dto_removeaddonrequest",
    "DtoResumeSubscriptionRequest": ".dto_resumesubscriptionrequest",
    "DtoResumeSubscriptionRequestTypedDict": ".dto_resumesubscriptionrequest",
    "DtoScheduledTaskResponse": ".dto_scheduledtaskresponse",
    "DtoScheduledTaskResponseTypedDict": ".dto_scheduledtaskresponse",
    "DtoSecretResponse": ".dto_secretresponse",
    "DtoSecretResponseTypedDict": ".dto_secretresponse",
    "DtoSourceUsageItem": ".dto_sourceusageitem",
    "DtoSourceUsageItemTypedDict": ".dto_sourceusageitem",
    "DtoSubscriptionChangeExecuteResponse": ".dto_subscriptionchangeexecuteresponse",
    "DtoSubscriptionChangeExecuteResponseTypedDict": ".dto_subscriptionchangeexecuteresponse",
    "DtoSubscriptionChangePreviewResponse": ".dto_subscriptionchangepreviewresponse",
    "DtoSubscriptionChangePreviewResponseTypedDict": ".dto_subscriptionchangepreviewresponse",
    "DtoSubscriptionChangeRequest": ".dto_subscriptionchangerequest",
    "DtoSubscriptionChangeRequestTypedDict": ".dto_subscriptionchangerequest",
    "DtoSubscriptionEntitlementsResponse": ".dto_subscriptionentitlementsresponse",
    "DtoSubscriptionEntitlementsResponseTypedDict": ".dto_subscriptionentitlementsresponse",
    "DtoSubscriptionLineItemLookupResult": ".dto_subscriptionlineitemlookupresult",
    "DtoSubscriptionLineItemLookupResultTypedDict": ".dto_subscriptionlineitemlookupresult",
    "DtoSubscriptionLineItemResponse": ".dto_subscriptionlineitemresponse",
    "DtoSubscriptionLineItemResponseTypedDict": ".dto_subscriptionlineitemresponse",
    "DtoSubscriptionPauseResponse": ".dto_subscriptionpauseresponse",
    "DtoSubscriptionPauseResponseTypedDict": ".dto_subscriptionpauseresponse",
    "DtoSubscriptionPhaseCreateRequest": ".dto_subscriptionphasecreaterequest",
    "DtoSubscriptionPhaseCreateRequestTypedDict": ".dto_subscriptionphasecreaterequest",
    "DtoSubscriptionPhaseResponse": ".dto_subscriptionphaseresponse",
    "DtoSubscriptionPhaseResponseTypedDict": ".dto_subscriptionphaseresponse",
    "DtoSubscriptionPriceCreateRequest": ".dto_subscriptionpricecreaterequest",
    "DtoSubscriptionPriceCreateRequestTypedDict": ".dto_subscriptionpricecreaterequest",
    "DtoSubscriptionResponseV2": ".dto_subscriptionresponsev2",
    "DtoSubscriptionResponseV2TypedDict": ".dto_subscriptionresponsev2",
    "Configuration": ".dto_subscriptionscheduleresponse",
    "ConfigurationTypedDict": ".dto_subscriptionscheduleresponse",
    "DtoSubscriptionScheduleResponse": ".dto_subscriptionscheduleresponse",
    "DtoSubscriptionScheduleResponseTypedDict": ".dto_subscriptionscheduleresponse",
    "ExecutionResult": ".dto_subscriptionscheduleresponse",
    "ExecutionResultTypedDict": ".dto_subscriptionscheduleresponse",
    "DtoSubscriptionSummary": ".dto_subscriptionsummary",
    "DtoSubscriptionSummaryTypedDict": ".dto_subscriptionsummary",
    "DtoSubscriptionUsageByMetersResponse": ".dto_subscriptionusagebymetersresponse",
    "DtoSubscriptionUsageByMetersResponseTypedDict": ".dto_subscriptionusagebymetersresponse",
    "DtoSuccessResponse": ".dto_successresponse",
    "DtoSuccessResponseTypedDict": ".dto_successresponse",
    "DtoTaskResponse": ".dto_taskresponse",
    "DtoTaskResponseTypedDict": ".dto_taskresponse",
    "DtoTaxAppliedResponse": ".dto_taxappliedresponse",
    "DtoTaxAppliedResponseTypedDict": ".dto_taxappliedresponse",
    "DtoTaxAssociationResponse": ".dto_taxassociationresponse",
    "DtoTaxAssociationResponseTypedDict": ".dto_taxassociationresponse",
    "DtoTaxAssociationUpdateRequest": ".dto_taxassociationupdaterequest",
    "DtoTaxAssociationUpdateRequestTypedDict": ".dto_taxassociationupdaterequest",
    "DtoTaxRateOverride": ".dto_taxrateoverride",
    "DtoTaxRateOverrideTypedDict": ".dto_taxrateoverride",
    "DtoTaxRateResponse": ".dto_taxrateresponse",
    "DtoTaxRateResponseTypedDict": ".dto_taxrateresponse",
    "DtoTenantBillingDetails": ".dto_tenantbillingdetails",
    "DtoTenantBillingDetailsTypedDict": ".dto_tenantbillingdetails",
    "DtoTenantBillingUsage": ".dto_tenantbillingusage",
    "DtoTenantBillingUsageTypedDict": ".dto_tenantbillingusage",
    "DtoTenantResponse": ".dto_tenantresponse",
    "DtoTenantResponseTypedDict": ".dto_tenantresponse",
    "DtoTopUpWalletRequest": ".dto_topupwalletrequest",
    "DtoTopUpWalletRequestTypedDict": ".dto_topupwalletrequest",
    "DtoTopUpWalletResponse": ".dto_topupwalletresponse",
    "DtoTopUpWalletResponseTypedDict": ".dto_topupwalletresponse",
    "DtoTriggerForceRunRequest": ".dto_triggerforcerunrequest",
    "DtoTriggerForceRunRequestTypedDict": ".dto_triggerforcerunrequest",
    "DtoTriggerForceRunResponse": ".dto_triggerforcerunresponse",
    "DtoTriggerForceRunResponseTypedDict": ".dto_triggerforcerunresponse",
    "DtoUpdateAddonRequest": ".dto_updateaddonrequest",
    "DtoUpdateAddonRequestTypedDict": ".dto_updateaddonrequest",
    "DtoUpdateCostsheetRequest": ".dto_updatecostsheetrequest",
    "DtoUpdateCostsheetRequestTypedDict": ".dto_updatecostsheetrequest",
    "DtoUpdateCostsheetResponse": ".dto_updatecostsheetresponse",
    "DtoUpdateCostsheetResponseTypedDict": ".dto_updatecostsheetresponse",
    "DtoUpdateCouponRequest": ".dto_updatecouponrequest",
    "DtoUpdateCouponRequestTypedDict": ".dto_updatecouponrequest",
    "DtoUpdateCreditGrantRequest": ".dto_updatecreditgrantrequest",
    "DtoUpdateCreditGrantRequestTypedDict": ".dto_updatecreditgrantrequest",
    "DtoUpdateCustomerRequest": ".dto_updatecustomerrequest",
    "DtoUpdateCustomerRequestTypedDict": ".dto_updatecustomerrequest",
    "DtoUpdateEntitlementRequest": ".dto_updateentitlementrequest",
    "DtoUpdateEntitlementRequestTypedDict": ".dto_updateentitlementrequest",
    "DtoUpdateEnvironmentRequest": ".dto_updateenvironmentrequest",
    "DtoUpdateEnvironmentRequestTypedDict": ".dto_updateenvironmentrequest",
    "DtoUpdateFeatureRequest": ".dto_updatefeaturerequest",
    "DtoUpdateFeatureRequestTypedDict": ".dto_updatefeaturerequest",
    "DtoUpdateInvoiceRequest": ".dto_updateinvoicerequest",
    "DtoUpdateInvoiceRequestTypedDict": ".dto_updateinvoicerequest",
    "DtoUpdatePaymentRequest": ".dto_updatepaymentrequest",
    "DtoUpdatePaymentRequestTypedDict": ".dto_updatepaymentrequest",
    "DtoUpdatePaymentStatusRequest": ".dto_updatepaymentstatusrequest",
    "DtoUpdatePaymentStatusRequestTypedDict": ".dto_updatepaymentstatusrequest",
    "DtoUpdatePlanRequest": ".dto_updateplanrequest",
    "DtoUpdatePlanRequestTypedDict": ".dto_updateplanrequest",
    "DtoUpdatePriceRequest": ".dto_updatepricerequest",
    "DtoUpdatePriceRequestTypedDict": ".dto_updatepricerequest",
    "DtoUpdatePriceUnitRequest": ".dto_updatepriceunitrequest",
    "DtoUpdatePriceUnitRequestTypedDict": ".dto_updatepriceunitrequest",
    "DtoUpdateScheduledTaskRequest": ".dto_updatescheduledtaskrequest",
    "DtoUpdateScheduledTaskRequestTypedDict": ".dto_updatescheduledtaskrequest",
    "DtoUpdateSubscriptionLineItemRequest": ".dto_updatesubscriptionlineitemrequest",
    "DtoUpdateSubscriptionLineItemRequestTypedDict": ".dto_updatesubscriptionlineitemrequest",
    "DtoUpdateSubscriptionRequest": ".dto_updatesubscriptionrequest",
    "DtoUpdateSubscriptionRequestTypedDict": ".dto_updatesubscriptionrequest",
    "DtoUpdateTaskStatusRequest": ".dto_updatetaskstatusrequest",
    "DtoUpdateTaskStatusRequestTypedDict": ".dto_updatetaskstatusrequest",
    "DtoUpdateTaxRateRequest": ".dto_updatetaxraterequest",
    "DtoUpdateTaxRateRequestTypedDict": ".dto_updatetaxraterequest",
    "DtoUpdateTenantRequest": ".dto_updatetenantrequest",
    "DtoUpdateTenantRequestTypedDict": ".dto_updatetenantrequest",
    "DtoUpdateWalletRequest": ".dto_updatewalletrequest",
    "DtoUpdateWalletRequestTypedDict": ".dto_updatewalletrequest",
    "DtoUsageAnalyticItem": ".dto_usageanalyticitem",
    "DtoUsageAnalyticItemTypedDict": ".dto_usageanalyticitem",
    "DtoUsageAnalyticPoint": ".dto_usageanalyticpoint",
    "DtoUsageAnalyticPointTypedDict": ".dto_usageanalyticpoint",
    "DtoUsageBreakdownItem": ".dto_usagebreakdownitem",
    "DtoUsageBreakdownItemTypedDict": ".dto_usagebreakdownitem",
    "DtoUsageResult": ".dto_usageresult",
    "DtoUsageResultTypedDict": ".dto_usageresult",
    "DtoUserResponse": ".dto_userresponse",
    "DtoUserResponseTypedDict": ".dto_userresponse",
    "DtoWalletBalanceResponse": ".dto_walletbalanceresponse",
    "DtoWalletBalanceResponseTypedDict": ".dto_walletbalanceresponse",
    "DtoWalletResponse": ".dto_walletresponse",
    "DtoWalletResponseTypedDict": ".dto_walletresponse",
    "DtoWalletTransactionResponse": ".dto_wallettransactionresponse",
    "DtoWalletTransactionResponseTypedDict": ".dto_wallettransactionresponse",
    "DTOWorkflowExecutionDTO": ".dto_workflowexecutiondto",
    "DTOWorkflowExecutionDTOTypedDict": ".dto_workflowexecutiondto",
    "EntitlementEntityType": ".entitlemententitytype",
    "EntitlementFilter": ".entitlementfilter",
    "EntitlementFilterOrder": ".entitlementfilter",
    "EntitlementFilterTypedDict": ".entitlementfilter",
    "EntitlementUsageResetPeriod": ".entitlementusageresetperiod",
    "EntityType": ".entitytype",
    "ErrorsErrorDetail": ".errors_errordetail",
    "ErrorsErrorDetailTypedDict": ".errors_errordetail",
    "ErrorsErrorResponse": ".errors_errorresponse",
    "ErrorsErrorResponseTypedDict": ".errors_errorresponse",
    "EventProcessingStatusType": ".eventprocessingstatustype",
    "FailurePoint": ".failurepoint",
    "FailurePointTypedDict": ".failurepoint",
    "FailurePointType": ".failurepointtype",
    "FeatureFilter": ".featurefilter",
    "FeatureFilterOrder": ".featurefilter",
    "FeatureFilterTypedDict": ".featurefilter",
    "FeatureType": ".featuretype",
    "FileType": ".filetype",
    "FilterCondition": ".filtercondition",
    "FilterConditionTypedDict": ".filtercondition",
    "FilterOperatorType": ".filteroperatortype",
    "GithubComFlexpriceFlexpriceInternalDomainAddonAddon": ".github_com_flexprice_flexprice_internal_domain_addon_addon",
    "GithubComFlexpriceFlexpriceInternalDomainAddonAddonTypedDict": ".github_com_flexprice_flexprice_internal_domain_addon_addon",
    "GithubComFlexpriceFlexpriceInternalDomainCouponCoupon": ".github_com_flexprice_flexprice_internal_domain_coupon_coupon",
    "GithubComFlexpriceFlexpriceInternalDomainCouponCouponTypedDict": ".github_com_flexprice_flexprice_internal_domain_coupon_coupon",
    "GithubComFlexpriceFlexpriceInternalDomainCustomerCustomer": ".github_com_flexprice_flexprice_internal_domain_customer_customer",
    "GithubComFlexpriceFlexpriceInternalDomainCustomerCustomerTypedDict": ".github_com_flexprice_flexprice_internal_domain_customer_customer",
    "GithubComFlexpriceFlexpriceInternalDomainFeatureFeature": ".github_com_flexprice_flexprice_internal_domain_feature_feature",
    "GithubComFlexpriceFlexpriceInternalDomainFeatureFeatureTypedDict": ".github_com_flexprice_flexprice_internal_domain_feature_feature",
    "GithubComFlexpriceFlexpriceInternalDomainPlanPlan": ".github_com_flexprice_flexprice_internal_domain_plan_plan",
    "GithubComFlexpriceFlexpriceInternalDomainPlanPlanTypedDict": ".github_com_flexprice_flexprice_internal_domain_plan_plan",
    "GithubComFlexpriceFlexpriceInternalTypesValue": ".github_com_flexprice_flexprice_internal_types_value",
    "GithubComFlexpriceFlexpriceInternalTypesValueTypedDict": ".github_com_flexprice_flexprice_internal_types_value",
    "GroupFilter": ".groupfilter",
    "GroupFilterOrder": ".groupfilter",
    "GroupFilterTypedDict": ".groupfilter",
    "IntegrationEntityType": ".integrationentitytype",
    "InvoiceBilling": ".invoicebilling",
    "InvoiceBillingReason": ".invoicebillingreason",
    "InvoiceCadence": ".invoicecadence",
    "InvoiceFilter": ".invoicefilter",
    "InvoiceFilterOrder": ".invoicefilter",
    "InvoiceFilterTypedDict": ".invoicefilter",
    "InvoiceStatus": ".invoicestatus",
    "InvoiceType": ".invoicetype",
    "ListResponseDtoWalletResponse": ".listresponse_dto_walletresponse",
    "ListResponseDtoWalletResponseTypedDict": ".listresponse_dto_walletresponse",
    "MeterAggregation": ".meter_aggregation",
    "MeterAggregationTypedDict": ".meter_aggregation",
    "MeterFilter": ".meter_filter",
    "MeterFilterTypedDict": ".meter_filter",
    "MeterMeter": ".meter_meter",
    "MeterMeterTypedDict": ".meter_meter",
    "ModelsTemporalWorkflowResult": ".models_temporalworkflowresult",
    "ModelsTemporalWorkflowResultTypedDict": ".models_temporalworkflowresult",
    "PaginationResponse": ".paginationresponse",
    "PaginationResponseTypedDict": ".paginationresponse",
    "PauseMode": ".pausemode",
    "PauseStatus": ".pausestatus",
    "PaymentBehavior": ".paymentbehavior",
    "PaymentDestinationType": ".paymentdestinationtype",
    "PaymentGatewayType": ".paymentgatewaytype",
    "PaymentMethodType": ".paymentmethodtype",
    "PaymentStatus": ".paymentstatus",
    "PaymentTerms": ".paymentterms",
    "PlanFilter": ".planfilter",
    "PlanFilterOrder": ".planfilter",
    "PlanFilterTypedDict": ".planfilter",
    "PriceJSONBTransformQuantity": ".price_jsonbtransformquantity",
    "PriceJSONBTransformQuantityTypedDict": ".price_jsonbtransformquantity",
    "PricePrice": ".price_price",
    "PricePriceTypedDict": ".price_price",
    "PricePriceTier": ".price_pricetier",
    "PricePriceTierTypedDict": ".price_pricetier",
    "PriceTransformQuantity": ".price_transformquantity",
    "PriceTransformQuantityTypedDict": ".price_transformquantity",
    "PriceEntityType": ".priceentitytype",
    "PriceFilter": ".pricefilter",
    "PriceFilterOrder": ".pricefilter",
    "PriceFilterTypedDict": ".pricefilter",
    "PriceType": ".pricetype",
    "PriceUnitFilter": ".priceunitfilter",
    "PriceUnitFilterOrder": ".priceunitfilter",
    "PriceUnitFilterTypedDict": ".priceunitfilter",
    "PriceUnitType": ".priceunittype",
    "ProrationBehavior": ".prorationbehavior",
    "QueryFilter": ".queryfilter",
    "QueryFilterOrder": ".queryfilter",
    "QueryFilterTypedDict": ".queryfilter",
    "ResetUsage": ".resetusage",
    "ResumeMode": ".resumemode",
    "RoundType": ".roundtype",
    "S3CompressionType": ".s3compressiontype",
    "S3EncryptionType": ".s3encryptiontype",
    "S3JobConfig": ".s3jobconfig",
    "S3JobConfigTypedDict": ".s3jobconfig",
    "ScheduledTaskEntityType": ".scheduledtaskentitytype",
    "ScheduledTaskInterval": ".scheduledtaskinterval",
    "ScheduleStatus": ".schedulestatus",
    "ScheduleType": ".scheduletype",
    "SecretProvider": ".secretprovider",
    "SecretType": ".secrettype",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "SortCondition": ".sortcondition",
    "SortConditionTypedDict": ".sortcondition",
    "SortDirection": ".sortdirection",
    "Status": ".status",
    "SubscriptionSubscriptionLineItem": ".subscription_subscriptionlineitem",
    "SubscriptionSubscriptionLineItemTypedDict": ".subscription_subscriptionlineitem",
    "SubscriptionSubscriptionPause": ".subscription_subscriptionpause",
    "SubscriptionSubscriptionPauseTypedDict": ".subscription_subscriptionpause",
    "SubscriptionChangeType": ".subscriptionchangetype",
    "SubscriptionFilter": ".subscriptionfilter",
    "SubscriptionFilterOrder": ".subscriptionfilter",
    "SubscriptionFilterTypedDict": ".subscriptionfilter",
    "SubscriptionLineItemEntityType": ".subscriptionlineitementitytype",
    "SubscriptionScheduleChangeType": ".subscriptionschedulechangetype",
    "SubscriptionStatus": ".subscriptionstatus",
    "TaskStatus": ".taskstatus",
    "TaskType": ".tasktype",
    "TaxRateEntityType": ".taxrateentitytype",
    "TaxRateScope": ".taxratescope",
    "TaxRateStatus": ".taxratestatus",
    "TaxRateType": ".taxratetype",
    "TimeRangeFilter": ".timerangefilter",
    "TimeRangeFilterTypedDict": ".timerangefilter",
    "TransactionReason": ".transactionreason",
    "TransactionStatus": ".transactionstatus",
    "TransactionType": ".transactiontype",
    "UserFilter": ".userfilter",
    "UserFilterOrder": ".userfilter",
    "UserFilterTypedDict": ".userfilter",
    "UserType": ".usertype",
    "WalletConfig": ".walletconfig",
    "WalletConfigTypedDict": ".walletconfig",
    "WalletConfigPriceType": ".walletconfigpricetype",
    "WalletFilter": ".walletfilter",
    "WalletFilterOrder": ".walletfilter",
    "WalletFilterTypedDict": ".walletfilter",
    "WalletStatus": ".walletstatus",
    "WalletTransactionFilter": ".wallettransactionfilter",
    "WalletTransactionFilterOrder": ".wallettransactionfilter",
    "WalletTransactionFilterTypedDict": ".wallettransactionfilter",
    "WalletTxReferenceType": ".wallettxreferencetype",
    "WalletType": ".wallettype",
    "WindowSize": ".windowsize",
    "WorkflowExecutionFilter": ".workflowexecutionfilter",
    "WorkflowExecutionFilterOrder": ".workflowexecutionfilter",
    "WorkflowExecutionFilterTypedDict": ".workflowexecutionfilter",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


FailurePointType = Union[
    Literal[
        "customer_lookup",
        "meter_lookup",
        "price_lookup",
        "subscription_line_item_lookup",
    ],
    UnrecognizedStr,
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .meter_aggregation import MeterAggregation, MeterAggregationTypedDict
from .meter_filter import MeterFilter, MeterFilterTypedDict
from .resetusage import ResetUsage
from .status import Status
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class MeterMeterTypedDict(TypedDict):
    aggregation: NotRequired[MeterAggregationTypedDict]
    created_at: NotRequired[str]
    created_by: NotRequired[str]
    environment_id: NotRequired[str]
    r"""EnvironmentID is the environment identifier for the meter"""
    event_name: NotRequired[str]
    r"""EventName is the unique identifier for the event that this meter is tracking
    It is a mandatory field in the events table and hence being used as the primary matching field
    We can have multiple meters tracking the same event but with different filters and aggregation
    """
    filters: NotRequired[List[MeterFilterTypedDict]]
    r"""Filters define the criteria for the meter to be applied on the events before aggregation
    It also defines the possible values on which later the charges will be applied
    """
    id: NotRequired[str]
    r"""ID is the unique identifier for the meter"""
    name: NotRequired[str]
    r"""Name is the display name of the meter"""
    reset_usage: NotRequired[ResetUsage]
    status: NotRequired[Status]
    tenant_id: NotRequired[str]
    updated_at: NotRequired[str]
    updated_by: NotRequired[str]


class MeterMeter(BaseModel):
    aggregation: Optional[MeterAggregation] = None

    created_at: Optional[str] = None

    created_by: Optional[str] = None

    environment_id: Optional[str] = None
    r"""EnvironmentID is the environment identifier for the meter"""

    event_name: Optional[str] = None
    r"""EventName is the unique identifier for the event that this meter is tracking
    It is a mandatory field in the events table and hence being used as the primary matching field
    We can have multiple meters tracking the same event but with different filters and aggregation
    """

    filters: Optional[List[MeterFilter]] = None
    r"""Filters define the criteria for the meter to be applied on the events before aggregation
    It also defines the possible values on which later the charges will be applied
    """

    id: Optional[str] = None
    r"""ID is the unique identifier for the meter"""

    name: Optional[str] = None
    r"""Name is the display name of the meter"""

    reset_usage: Optional[ResetUsage] = None

    status: Optional[Status] = None

    tenant_id: Optional[str] = None

    updated_at: Optional[str] = None

    updated_by: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "aggregation",
                "created_at",
                "created_by",
                "environment_id",
                "event_name",
                "filters",
                "id",
                "name",
                "reset_usage",
                "status",
                "tenant_id",
                "updated_at",
                "updated_by",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
